<?php
// analytics/financial_analysis.php - 财务数据分析
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化筛选参数
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'month';
$year = isset($_GET['year']) ? intval($_GET['year']) : date('Y');
$month = isset($_GET['month']) ? intval($_GET['month']) : date('n');

// 设置日期范围
switch ($date_range) {
    case 'month':
        $date_from = date('Y-m-01');
        $date_to = date('Y-m-t');
        break;
    case 'quarter':
        $quarter = ceil(date('n') / 3);
        $date_from = date('Y-m-d', mktime(0, 0, 0, ($quarter - 1) * 3 + 1, 1, date('Y')));
        $date_to = date('Y-m-d', mktime(0, 0, 0, $quarter * 3 + 1, 0, date('Y')));
        break;
    case 'year':
        $date_from = date('Y-01-01');
        $date_to = date('Y-12-31');
        break;
    case 'custom':
        $date_from = isset($_GET['date_from']) ? $_GET['date_from'] : date('Y-m-01');
        $date_to = isset($_GET['date_to']) ? $_GET['date_to'] : date('Y-m-t');
        break;
    default:
        $date_from = date('Y-m-01');
        $date_to = date('Y-m-t');
}

// 获取销售收入数据
try {
    $sql = "
        SELECT 
            SUM(total_amount) AS total_sales,
            COUNT(*) AS order_count,
            AVG(total_amount) AS avg_order_value
        FROM 
            sales_orders
        WHERE 
            order_date BETWEEN ? AND ?
            AND status != 'canceled'
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$date_from, $date_to]);
    $sales_data = $stmt->fetch();
} catch (PDOException $e) {
    $error = "获取销售收入数据失败: " . $e->getMessage();
}

// 获取采购支出数据
try {
    $sql = "
        SELECT 
            SUM(total_amount) AS total_purchase,
            COUNT(*) AS purchase_count,
            AVG(total_amount) AS avg_purchase_value
        FROM 
            purchase_orders
        WHERE 
            order_date BETWEEN ? AND ?
            AND status != 'canceled'
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$date_from, $date_to]);
    $purchase_data = $stmt->fetch();
} catch (PDOException $e) {
    $error = "获取采购支出数据失败: " . $e->getMessage();
}

// 计算毛利润
$gross_profit = ($sales_data['total_sales'] ?? 0) - ($purchase_data['total_purchase'] ?? 0);
$gross_profit_margin = ($sales_data['total_sales'] > 0) ? ($gross_profit / $sales_data['total_sales'] * 100) : 0;

// 获取月度销售收入趋势
try {
    $sql = "
        SELECT 
            DATE_FORMAT(order_date, '%Y-%m') AS month,
            SUM(total_amount) AS monthly_sales
        FROM 
            sales_orders
        WHERE 
            order_date BETWEEN DATE_SUB(?, INTERVAL 11 MONTH) AND ?
            AND status != 'canceled'
        GROUP BY 
            DATE_FORMAT(order_date, '%Y-%m')
        ORDER BY 
            month
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$date_to, $date_to]);
    $monthly_sales = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取月度销售趋势数据失败: " . $e->getMessage();
}

// 获取月度采购支出趋势
try {
    $sql = "
        SELECT 
            DATE_FORMAT(order_date, '%Y-%m') AS month,
            SUM(total_amount) AS monthly_purchase
        FROM 
            purchase_orders
        WHERE 
            order_date BETWEEN DATE_SUB(?, INTERVAL 11 MONTH) AND ?
            AND status != 'canceled'
        GROUP BY 
            DATE_FORMAT(order_date, '%Y-%m')
        ORDER BY 
            month
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$date_to, $date_to]);
    $monthly_purchase = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取月度采购趋势数据失败: " . $e->getMessage();
}

// 准备图表数据 - 月度财务趋势
$months = [];
$sales_trend = [];
$purchase_trend = [];
$profit_trend = [];

// 创建完整的月份数组，最近12个月
$end_month = date('Y-m', strtotime($date_to));
for ($i = 11; $i >= 0; $i--) {
    $month_key = date('Y-m', strtotime("$end_month -$i months"));
    $months[] = $month_key;
    $sales_trend[$month_key] = 0;
    $purchase_trend[$month_key] = 0;
}

// 填充销售数据
foreach ($monthly_sales as $item) {
    if (isset($sales_trend[$item['month']])) {
        $sales_trend[$item['month']] = floatval($item['monthly_sales']);
    }
}

// 填充采购数据
foreach ($monthly_purchase as $item) {
    if (isset($purchase_trend[$item['month']])) {
        $purchase_trend[$item['month']] = floatval($item['monthly_purchase']);
    }
}

// 计算利润数据
foreach ($months as $month) {
    $profit_trend[$month] = $sales_trend[$month] - $purchase_trend[$month];
}

// 转换为数组
$months_array = array_values($months);
$sales_array = array_values($sales_trend);
$purchase_array = array_values($purchase_trend);
$profit_array = array_values($profit_trend);
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>财务数据分析 - FruitEase</title>
    <link rel="stylesheet" href="https://cdn.bootcdn.net/ajax/libs/bootstrap/5.1.3/css/bootstrap.min.css">
    <script src="https://cdn.bootcdn.net/ajax/libs/echarts/5.3.3/echarts.min.js"></script>
    <style>
        .card {
            margin-bottom: 20px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .chart-container {
            height: 400px;
            margin-bottom: 20px;
        }

        .stat-card {
            text-align: center;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            color: white;
        }

        .income-card {
            background: linear-gradient(135deg, #2ecc71, #27ae60);
        }

        .expense-card {
            background: linear-gradient(135deg, #e74c3c, #c0392b);
        }

        .profit-card {
            background: linear-gradient(135deg, #3498db, #2980b9);
        }

        .tax-card {
            background: linear-gradient(135deg, #f39c12, #d35400);
        }

        .stat-card h2 {
            font-size: 24px;
            margin-bottom: 10px;
        }

        .stat-card p {
            font-size: 28px;
            font-weight: bold;
            margin: 0;
        }

        .stat-card small {
            font-size: 14px;
            opacity: 0.8;
        }

        .nav-pills .nav-link.active {
            background-color: #3498db;
        }

        .positive {
            color: #2ecc71;
            font-weight: bold;
        }

        .negative {
            color: #e74c3c;
            font-weight: bold;
        }
    </style>
</head>

<body class="bg-light">
    <div class="container-fluid py-4">
        <h1 class="mb-4">财务数据分析</h1>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <!-- 筛选器 -->
        <div class="card mb-4">
            <div class="card-body">
                <form method="get" class="row">
                    <div class="col-md-3 mb-3">
                        <label for="date_range" class="form-label">时间范围</label>
                        <select id="date_range" name="date_range" class="form-select" onchange="toggleCustomDate()">
                            <option value="month" <?= $date_range == 'month' ? 'selected' : '' ?>>本月</option>
                            <option value="quarter" <?= $date_range == 'quarter' ? 'selected' : '' ?>>本季度</option>
                            <option value="year" <?= $date_range == 'year' ? 'selected' : '' ?>>本年度</option>
                            <option value="custom" <?= $date_range == 'custom' ? 'selected' : '' ?>>自定义</option>
                        </select>
                    </div>

                    <div id="custom_date" class="col-md-6 mb-3" style="display: <?= $date_range == 'custom' ? 'flex' : 'none' ?>">
                        <div class="row">
                            <div class="col-6">
                                <label for="date_from" class="form-label">开始日期</label>
                                <input type="date" id="date_from" name="date_from" class="form-control" value="<?= $date_from ?>">
                            </div>
                            <div class="col-6">
                                <label for="date_to" class="form-label">结束日期</label>
                                <input type="date" id="date_to" name="date_to" class="form-control" value="<?= $date_to ?>">
                            </div>
                        </div>
                    </div>

                    <div class="col-md-3 mb-3 d-flex align-items-end">
                        <button type="submit" class="btn btn-primary w-100">应用筛选</button>
                    </div>
                </form>
            </div>
        </div>

        <!-- 财务统计卡片 -->
        <div class="row mb-4">
            <div class="col-md-3">
                <div class="stat-card income-card">
                    <h2>销售收入</h2>
                    <p>¥<?= number_format($sales_data['total_sales'] ?? 0, 2) ?></p>
                    <small>总销售订单: <?= number_format($sales_data['order_count'] ?? 0) ?></small>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stat-card expense-card">
                    <h2>采购支出</h2>
                    <p>¥<?= number_format($purchase_data['total_purchase'] ?? 0, 2) ?></p>
                    <small>总采购订单: <?= number_format($purchase_data['purchase_count'] ?? 0) ?></small>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stat-card profit-card">
                    <h2>毛利润</h2>
                    <p>¥<?= number_format($gross_profit, 2) ?></p>
                    <small>毛利率: <?= number_format($gross_profit_margin, 2) ?>%</small>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stat-card tax-card">
                    <h2>增值税估算</h2>
                    <p>¥<?= number_format($sales_data['total_sales'] * 0.13 ?? 0, 2) ?></p>
                    <small>按13%增值税率估算</small>
                </div>
            </div>
        </div>

        <!-- 分析内容 -->
        <div class="card">
            <div class="card-header">
                <ul class="nav nav-pills" id="financeTab" role="tablist">
                    <li class="nav-item" role="presentation">
                        <button class="nav-link active" id="trends-tab" data-bs-toggle="tab" data-bs-target="#trends-tab-pane" type="button" role="tab">财务趋势</button>
                    </li>
                    <li class="nav-item" role="presentation">
                        <button class="nav-link" id="profitability-tab" data-bs-toggle="tab" data-bs-target="#profitability-tab-pane" type="button" role="tab">盈利能力分析</button>
                    </li>
                    <li class="nav-item" role="presentation">
                        <button class="nav-link" id="tax-tab" data-bs-toggle="tab" data-bs-target="#tax-tab-pane" type="button" role="tab">税务分析</button>
                    </li>
                </ul>
            </div>
            <div class="card-body">
                <div class="tab-content" id="financeTabContent">
                    <!-- 财务趋势 -->
                    <div class="tab-pane fade show active" id="trends-tab-pane" role="tabpanel" tabindex="0">
                        <h2 class="mb-4">月度财务趋势 (最近12个月)</h2>
                        <div id="trendChart" class="chart-container"></div>

                        <div class="table-responsive mt-4">
                            <table class="table table-striped table-hover">
                                <thead>
                                    <tr>
                                        <th>月份</th>
                                        <th>销售收入 (¥)</th>
                                        <th>采购支出 (¥)</th>
                                        <th>毛利润 (¥)</th>
                                        <th>毛利率</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($months as $i => $month): ?>
                                        <tr>
                                            <td><?= $month ?></td>
                                            <td>¥<?= number_format($sales_trend[$month], 2) ?></td>
                                            <td>¥<?= number_format($purchase_trend[$month], 2) ?></td>
                                            <td>
                                                <?php if ($profit_trend[$month] >= 0): ?>
                                                    <span class="positive">¥<?= number_format($profit_trend[$month], 2) ?></span>
                                                <?php else: ?>
                                                    <span class="negative">¥<?= number_format($profit_trend[$month], 2) ?></span>
                                                <?php endif; ?>
                                            </td>
                                            <td>
                                                <?php
                                                $margin = $sales_trend[$month] > 0 ? $profit_trend[$month] / $sales_trend[$month] * 100 : 0;
                                                if ($margin >= 0):
                                                ?>
                                                    <span class="positive"><?= number_format($margin, 2) ?>%</span>
                                                <?php else: ?>
                                                    <span class="negative"><?= number_format($margin, 2) ?>%</span>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>

                    <!-- 盈利能力分析 -->
                    <div class="tab-pane fade" id="profitability-tab-pane" role="tabpanel" tabindex="0">
                        <h2 class="mb-4">盈利能力分析</h2>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="card">
                                    <div class="card-body">
                                        <h3 class="card-title">毛利率趋势</h3>
                                        <div id="marginChart" class="chart-container"></div>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="card">
                                    <div class="card-body">
                                        <h3 class="card-title">盈利能力指标</h3>
                                        <table class="table">
                                            <tbody>
                                                <tr>
                                                    <td>毛利率</td>
                                                    <td><?= number_format($gross_profit_margin, 2) ?>%</td>
                                                </tr>
                                                <tr>
                                                    <td>平均订单金额</td>
                                                    <td>¥<?= number_format($sales_data['avg_order_value'] ?? 0, 2) ?></td>
                                                </tr>
                                                <tr>
                                                    <td>销售/采购比率</td>
                                                    <td><?= number_format(($purchase_data['total_purchase'] > 0) ? $sales_data['total_sales'] / $purchase_data['total_purchase'] : 0, 2) ?></td>
                                                </tr>
                                            </tbody>
                                        </table>

                                        <h4 class="mt-4">盈利能力改进建议</h4>
                                        <ul>
                                            <li>优化产品组合，增加高毛利产品的销售比重</li>
                                            <li>寻找更优惠的供应渠道，降低采购成本</li>
                                            <li>提高运营效率，减少废品和损耗</li>
                                            <li>适度调整产品定价策略</li>
                                            <li>增强供应链管理，优化库存周转</li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- 税务分析 -->
                    <div class="tab-pane fade" id="tax-tab-pane" role="tabpanel" tabindex="0">
                        <h2 class="mb-4">税务分析</h2>

                        <div class="alert alert-info">
                            <h4>税务分析说明</h4>
                            <p>本分析基于对当前销售和采购数据的估算，具体税务处理请咨询专业会计师。以下是对主要税种的估算：</p>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="card">
                                    <div class="card-header">增值税估算</div>
                                    <div class="card-body">
                                        <table class="table">
                                            <tbody>
                                                <tr>
                                                    <td>销项税额 (销售额 × 13%)</td>
                                                    <td>¥<?= number_format($sales_data['total_sales'] * 0.13 ?? 0, 2) ?></td>
                                                </tr>
                                                <tr>
                                                    <td>进项税额 (采购额 × 13%)</td>
                                                    <td>¥<?= number_format($purchase_data['total_purchase'] * 0.13 ?? 0, 2) ?></td>
                                                </tr>
                                                <tr>
                                                    <td>应纳增值税 (销项税额 - 进项税额)</td>
                                                    <td>¥<?= number_format(($sales_data['total_sales'] * 0.13) - ($purchase_data['total_purchase'] * 0.13) ?? 0, 2) ?></td>
                                                </tr>
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="card">
                                    <div class="card-header">企业所得税估算</div>
                                    <div class="card-body">
                                        <table class="table">
                                            <tbody>
                                                <tr>
                                                    <td>估算应纳税所得额</td>
                                                    <td>¥<?= number_format($gross_profit * 0.7 ?? 0, 2) ?></td>
                                                </tr>
                                                <tr>
                                                    <td>估算企业所得税 (25%)</td>
                                                    <td>¥<?= number_format($gross_profit * 0.7 * 0.25 ?? 0, 2) ?></td>
                                                </tr>
                                            </tbody>
                                        </table>

                                        <div class="alert alert-warning mt-3">
                                            <small>注意：实际所得税计算需考虑各项费用、折旧、摊销等因素，此处仅为简化估算。</small>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="card mt-4">
                            <div class="card-header">税务优化建议</div>
                            <div class="card-body">
                                <ul>
                                    <li>确保所有采购发票合规，以便充分抵扣进项税</li>
                                    <li>考虑利用税收优惠政策，如研发费用加计扣除</li>
                                    <li>合理安排采购与销售时间，优化税收流量</li>
                                    <li>定期进行税务自检，避免税务风险</li>
                                    <li>咨询专业会计师，制定合理税务筹划方案</li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.bootcdn.net/ajax/libs/bootstrap/5.1.3/js/bootstrap.bundle.min.js"></script>
    <script>
        // 切换自定义日期
        function toggleCustomDate() {
            var dateRange = document.getElementById('date_range').value;
            var customDate = document.getElementById('custom_date');
            customDate.style.display = (dateRange === 'custom') ? 'flex' : 'none';
        }

        // 初始化ECharts
        document.addEventListener('DOMContentLoaded', function() {
            // 财务趋势图表
            var trendChart = echarts.init(document.getElementById('trendChart'));
            var trendOption = {
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'cross',
                        label: {
                            backgroundColor: '#6a7985'
                        }
                    }
                },
                legend: {
                    data: ['销售收入', '采购支出', '毛利润']
                },
                grid: {
                    left: '3%',
                    right: '4%',
                    bottom: '3%',
                    containLabel: true
                },
                xAxis: {
                    type: 'category',
                    boundaryGap: false,
                    data: <?= json_encode($months_array) ?>
                },
                yAxis: {
                    type: 'value',
                    axisLabel: {
                        formatter: '¥{value}'
                    }
                },
                series: [{
                        name: '销售收入',
                        type: 'line',
                        stack: 'Total',
                        areaStyle: {},
                        emphasis: {
                            focus: 'series'
                        },
                        data: <?= json_encode($sales_array) ?>,
                        itemStyle: {
                            color: '#2ecc71'
                        }
                    },
                    {
                        name: '采购支出',
                        type: 'line',
                        stack: 'Total',
                        areaStyle: {},
                        emphasis: {
                            focus: 'series'
                        },
                        data: <?= json_encode($purchase_array) ?>,
                        itemStyle: {
                            color: '#e74c3c'
                        }
                    },
                    {
                        name: '毛利润',
                        type: 'line',
                        emphasis: {
                            focus: 'series'
                        },
                        data: <?= json_encode($profit_array) ?>,
                        itemStyle: {
                            color: '#3498db'
                        }
                    }
                ]
            };
            trendChart.setOption(trendOption);

            // 毛利率趋势图表
            var marginChart = echarts.init(document.getElementById('marginChart'));

            // 计算毛利率
            var margin_data = [];
            for (var i = 0; i < <?= count($months_array) ?>; i++) {
                if (<?= json_encode($sales_array) ?>[i] > 0) {
                    margin_data.push((<?= json_encode($profit_array) ?>[i] / <?= json_encode($sales_array) ?>[i] * 100).toFixed(2));
                } else {
                    margin_data.push(0);
                }
            }

            var marginOption = {
                tooltip: {
                    trigger: 'axis',
                    formatter: '{b}: {c}%'
                },
                grid: {
                    left: '3%',
                    right: '4%',
                    bottom: '3%',
                    containLabel: true
                },
                xAxis: {
                    type: 'category',
                    data: <?= json_encode($months_array) ?>
                },
                yAxis: {
                    type: 'value',
                    axisLabel: {
                        formatter: '{value}%'
                    }
                },
                series: [{
                    name: '毛利率',
                    type: 'line',
                    data: margin_data,
                    markLine: {
                        data: [{
                            type: 'average',
                            name: '平均值',
                            label: {
                                formatter: '平均毛利率: {c}%'
                            }
                        }]
                    },
                    itemStyle: {
                        color: function(params) {
                            var value = params.value;
                            if (value >= 30) {
                                return '#2ecc71';
                            } else if (value >= 15) {
                                return '#f39c12';
                            } else {
                                return '#e74c3c';
                            }
                        }
                    }
                }]
            };
            marginChart.setOption(marginOption);

            // 响应窗口大小变化
            window.addEventListener('resize', function() {
                trendChart.resize();
                marginChart.resize();
            });
        });
    </script>
</body>

</html>