<?php
// analytics/production_analysis.php - 生产数据分析
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化筛选参数
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'month';
$product_id = isset($_GET['product_id']) ? intval($_GET['product_id']) : 0;

// 设置日期范围
switch ($date_range) {
    case 'week':
        $date_from = date('Y-m-d', strtotime('-1 week'));
        $date_to = date('Y-m-d');
        break;
    case 'month':
        $date_from = date('Y-m-d', strtotime('-1 month'));
        $date_to = date('Y-m-d');
        break;
    case 'quarter':
        $date_from = date('Y-m-d', strtotime('-3 month'));
        $date_to = date('Y-m-d');
        break;
    case 'year':
        $date_from = date('Y-m-d', strtotime('-1 year'));
        $date_to = date('Y-m-d');
        break;
    case 'custom':
        $date_from = isset($_GET['date_from']) ? $_GET['date_from'] : date('Y-m-d', strtotime('-1 month'));
        $date_to = isset($_GET['date_to']) ? $_GET['date_to'] : date('Y-m-d');
        break;
    default:
        $date_from = date('Y-m-d', strtotime('-1 month'));
        $date_to = date('Y-m-d');
}

// 获取所有产品
try {
    $stmt = $pdo->query("SELECT id, name FROM products ORDER BY name");
    $products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取产品列表失败: " . $e->getMessage();
}

// 获取生产总览数据
try {
    $sql = "
        SELECT 
            COUNT(*) AS total_batches,
            SUM(quantity_planned) AS total_planned,
            SUM(quantity_produced) AS total_produced,
            AVG(quantity_produced / quantity_planned * 100) AS avg_completion_rate
        FROM 
            production_batches
        WHERE 
            start_time BETWEEN ? AND ?
    ";

    $params = [$date_from, $date_to];

    if ($product_id > 0) {
        $sql .= " AND product_id = ?";
        $params[] = $product_id;
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $production_overview = $stmt->fetch();
} catch (PDOException $e) {
    $error = "获取生产总览数据失败: " . $e->getMessage();
}

// 获取时间序列生产数据
try {
    // 根据选择的时间范围确定分组方式
    switch ($date_range) {
        case 'week':
            $group_by = "DATE(start_time)";
            $format = "%Y-%m-%d";
            $label = "日期";
            break;
        case 'month':
        case 'quarter':
            $group_by = "DATE(start_time)";
            $format = "%Y-%m-%d";
            $label = "日期";
            break;
        case 'year':
            $group_by = "DATE_FORMAT(start_time, '%Y-%m')";
            $format = "%Y-%m";
            $label = "月份";
            break;
        default:
            $group_by = "DATE(start_time)";
            $format = "%Y-%m-%d";
            $label = "日期";
    }

    $sql = "
        SELECT 
            DATE_FORMAT(start_time, '$format') AS time_period,
            COUNT(*) AS batch_count,
            SUM(quantity_planned) AS planned_quantity,
            SUM(quantity_produced) AS actual_quantity
        FROM 
            production_batches
        WHERE 
            start_time BETWEEN ? AND ?
    ";

    $params = [$date_from, $date_to];

    if ($product_id > 0) {
        $sql .= " AND product_id = ?";
        $params[] = $product_id;
    }

    $sql .= " GROUP BY DATE_FORMAT(start_time, '$format') ORDER BY time_period";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $time_series_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取时间序列生产数据失败: " . $e->getMessage();
}

// 获取产品生产分布
try {
    $sql = "
        SELECT 
            p.name AS product_name,
            COUNT(pb.id) AS batch_count,
            SUM(pb.quantity_planned) AS planned_quantity,
            SUM(pb.quantity_produced) AS actual_quantity,
            AVG(pb.quantity_produced / pb.quantity_planned * 100) AS completion_rate
        FROM 
            production_batches pb
        JOIN 
            products p ON pb.product_id = p.id
        WHERE 
            pb.start_time BETWEEN ? AND ?
        GROUP BY 
            pb.product_id
        ORDER BY 
            actual_quantity DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$date_from, $date_to]);
    $product_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取产品生产分布失败: " . $e->getMessage();
}

// 获取质量检测数据
try {
    $sql = "
        SELECT 
            pb.id AS production_batch_id,
            pb.batch_number,
            p.name AS product_name,
            DATE_FORMAT(pb.end_time, '%Y-%m-%d') AS completion_date,
            COUNT(*) AS total_tests,
            SUM(CASE WHEN qcfgt.result = 'passed' THEN 1 ELSE 0 END) AS passed_tests
        FROM 
            production_batches pb
        JOIN 
            products p ON pb.product_id = p.id
        LEFT JOIN 
            qc_finished_goods_tests qcfgt ON pb.id = qcfgt.production_batch_id
        WHERE 
            pb.end_time BETWEEN ? AND ?
            AND pb.status = 'completed'
    ";

    $params = [$date_from, $date_to];

    if ($product_id > 0) {
        $sql .= " AND pb.product_id = ?";
        $params[] = $product_id;
    }

    $sql .= " GROUP BY pb.id, pb.batch_number, p.name, pb.end_time ORDER BY pb.end_time DESC LIMIT 10";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $quality_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取质量检测数据失败: " . $e->getMessage();
    $quality_data = [];
}

// 获取生产效率数据
try {
    $sql = "
        SELECT 
            pb.id,
            pb.batch_number,
            p.name AS product_name,
            DATE_FORMAT(pb.start_time, '%Y-%m-%d') AS start_date,
            DATE_FORMAT(pb.end_time, '%Y-%m-%d') AS completion_date,
            DATEDIFF(pb.end_time, pb.start_time) AS duration_days,
            pb.quantity_planned AS planned_quantity,
            pb.quantity_produced AS actual_quantity,
            (pb.quantity_produced / pb.quantity_planned * 100) AS completion_rate
        FROM 
            production_batches pb
        JOIN 
            products p ON pb.product_id = p.id
        WHERE 
            pb.start_time BETWEEN ? AND ?
            AND pb.status = 'completed'
    ";

    $params = [$date_from, $date_to];

    if ($product_id > 0) {
        $sql .= " AND pb.product_id = ?";
        $params[] = $product_id;
    }

    $sql .= " ORDER BY pb.end_time DESC LIMIT 10";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $efficiency_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取生产效率数据失败: " . $e->getMessage();
    $efficiency_data = [];
}

// 准备图表数据
$chart_labels = [];
$chart_planned = [];
$chart_actual = [];
$chart_batches = [];

if (!empty($time_series_data)) {
    foreach ($time_series_data as $item) {
        $chart_labels[] = $item['time_period'];
        $chart_planned[] = $item['planned_quantity'];
        $chart_actual[] = $item['actual_quantity'];
        $chart_batches[] = $item['batch_count'];
    }
}

// 准备质量图表数据
$quality_labels = [];
$quality_pass_rates = [];

if (!empty($quality_data)) {
    foreach ($quality_data as $item) {
        $quality_labels[] = $item['batch_number'] . ' - ' . $item['product_name'];
        $pass_rate = ($item['total_tests'] > 0) ? ($item['passed_tests'] / $item['total_tests'] * 100) : 0;
        $quality_pass_rates[] = round($pass_rate, 2);
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>生产数据分析 - <?= title ?></title>
    <link rel="stylesheet" href="https://cdn.bootcdn.net/ajax/libs/bootstrap/5.1.3/css/bootstrap.min.css">
    <script src="https://cdn.bootcdn.net/ajax/libs/echarts/5.3.3/echarts.min.js"></script>
    <style>
        .card {
            margin-bottom: 20px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .chart-container {
            height: 400px;
            margin-bottom: 20px;
        }

        .stat-card {
            text-align: center;
            padding: 20px;
            background: linear-gradient(135deg, #2ecc71, #27ae60);
            color: white;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }

        .stat-card h2 {
            font-size: 24px;
            margin-bottom: 10px;
        }

        .stat-card p {
            font-size: 28px;
            font-weight: bold;
            margin: 0;
        }

        .stat-card small {
            font-size: 14px;
            opacity: 0.8;
        }

        .nav-pills .nav-link.active {
            background-color: #2ecc71;
        }
    </style>
</head>

<body class="bg-light">
    <div class="container-fluid py-4">
        <h1 class="mb-4">生产数据分析</h1>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <!-- 筛选器 -->
        <div class="card mb-4">
            <div class="card-body">
                <form method="get" class="row">
                    <div class="col-md-3 mb-3">
                        <label for="date_range" class="form-label">时间范围</label>
                        <select id="date_range" name="date_range" class="form-select" onchange="toggleCustomDate()">
                            <option value="week" <?= $date_range == 'week' ? 'selected' : '' ?>>最近一周</option>
                            <option value="month" <?= $date_range == 'month' ? 'selected' : '' ?>>最近一个月</option>
                            <option value="quarter" <?= $date_range == 'quarter' ? 'selected' : '' ?>>最近一个季度</option>
                            <option value="year" <?= $date_range == 'year' ? 'selected' : '' ?>>最近一年</option>
                            <option value="custom" <?= $date_range == 'custom' ? 'selected' : '' ?>>自定义</option>
                        </select>
                    </div>

                    <div id="custom_date" class="col-md-4 mb-3" style="display: <?= $date_range == 'custom' ? 'block' : 'none' ?>">
                        <div class="row">
                            <div class="col-6">
                                <label for="date_from" class="form-label">开始日期</label>
                                <input type="date" id="date_from" name="date_from" class="form-control" value="<?= $date_from ?>">
                            </div>
                            <div class="col-6">
                                <label for="date_to" class="form-label">结束日期</label>
                                <input type="date" id="date_to" name="date_to" class="form-control" value="<?= $date_to ?>">
                            </div>
                        </div>
                    </div>

                    <div class="col-md-3 mb-3">
                        <label for="product_id" class="form-label">产品</label>
                        <select id="product_id" name="product_id" class="form-select">
                            <option value="0">所有产品</option>
                            <?php foreach ($products as $product): ?>
                                <option value="<?= $product['id'] ?>" <?= $product_id == $product['id'] ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($product['name']) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="col-md-2 mb-3 d-flex align-items-end">
                        <button type="submit" class="btn btn-primary w-100">应用筛选</button>
                    </div>
                </form>
            </div>
        </div>

        <!-- 生产统计卡片 -->
        <div class="row mb-4">
            <div class="col-md-3">
                <div class="stat-card">
                    <h2>总批次数</h2>
                    <p><?= number_format($production_overview['total_batches'] ?? 0) ?></p>
                    <small>所选时间段内的生产批次总数</small>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stat-card">
                    <h2>计划生产量</h2>
                    <p><?= number_format($production_overview['total_planned'] ?? 0) ?></p>
                    <small>所选时间段内的计划生产总量</small>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stat-card">
                    <h2>实际生产量</h2>
                    <p><?= number_format($production_overview['total_produced'] ?? 0) ?></p>
                    <small>所选时间段内的实际生产总量</small>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stat-card">
                    <h2>平均完成率</h2>
                    <p><?= number_format($production_overview['avg_completion_rate'] ?? 0, 2) ?>%</p>
                    <small>所选时间段内的平均计划完成率</small>
                </div>
            </div>
        </div>

        <!-- 分析内容 -->
        <div class="card">
            <div class="card-header">
                <ul class="nav nav-pills" id="productionTab" role="tablist">
                    <li class="nav-item" role="presentation">
                        <button class="nav-link active" id="trend-tab" data-bs-toggle="tab" data-bs-target="#trend-tab-pane" type="button" role="tab">生产趋势</button>
                    </li>
                    <li class="nav-item" role="presentation">
                        <button class="nav-link" id="product-tab" data-bs-toggle="tab" data-bs-target="#product-tab-pane" type="button" role="tab">产品分析</button>
                    </li>
                    <li class="nav-item" role="presentation">
                        <button class="nav-link" id="quality-tab" data-bs-toggle="tab" data-bs-target="#quality-tab-pane" type="button" role="tab">质量分析</button>
                    </li>
                    <li class="nav-item" role="presentation">
                        <button class="nav-link" id="efficiency-tab" data-bs-toggle="tab" data-bs-target="#efficiency-tab-pane" type="button" role="tab">效率分析</button>
                    </li>
                </ul>
            </div>
            <div class="card-body">
                <div class="tab-content" id="productionTabContent">
                    <!-- 生产趋势 -->
                    <div class="tab-pane fade show active" id="trend-tab-pane" role="tabpanel" aria-labelledby="trend-tab" tabindex="0">
                        <div class="chart-container">
                            <div id="productionTrendChart" style="width: 100%; height: 100%;"></div>
                        </div>
                        <div class="mt-3 mb-5">
                            <h3>生产趋势分析</h3>
                            <p>
                                该图表显示了所选时间段内计划生产量和实际生产量的变化趋势。通过观察趋势，可以识别生产高峰和低谷，
                                评估生产计划的执行情况，为生产计划调整和资源分配提供依据。同时，生产批次数量的变化也反映了生产活动的频率。
                            </p>
                        </div>
                    </div>

                    <!-- 产品分析 -->
                    <div class="tab-pane fade" id="product-tab-pane" role="tabpanel" aria-labelledby="product-tab" tabindex="0">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="chart-container">
                                    <div id="productPieChart" style="width: 100%; height: 100%;"></div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="table-responsive">
                                    <table class="table table-bordered table-striped">
                                        <thead class="table-light">
                                            <tr>
                                                <th>产品</th>
                                                <th>批次数</th>
                                                <th>计划量</th>
                                                <th>实际量</th>
                                                <th>完成率</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach ($product_data as $item): ?>
                                                <tr>
                                                    <td><?= htmlspecialchars($item['product_name']) ?></td>
                                                    <td><?= number_format($item['batch_count']) ?></td>
                                                    <td><?= number_format($item['planned_quantity']) ?></td>
                                                    <td><?= number_format($item['actual_quantity']) ?></td>
                                                    <td><?= number_format($item['completion_rate'], 2) ?>%</td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                        </div>
                        <div class="mt-3 mb-5">
                            <h3>产品生产分析</h3>
                            <p>
                                该图表和表格展示了不同产品的生产情况。通过产品分析，可以了解各产品的生产比重，评估产品结构的合理性，
                                发现完成率较低的产品，针对性地提高生产效率，优化产品生产策略。
                            </p>
                        </div>
                    </div>

                    <!-- 质量分析 -->
                    <div class="tab-pane fade" id="quality-tab-pane" role="tabpanel" aria-labelledby="quality-tab" tabindex="0">
                        <div class="chart-container">
                            <div id="qualityBarChart" style="width: 100%; height: 100%;"></div>
                        </div>
                        <div class="mt-3">
                            <div class="table-responsive">
                                <table class="table table-bordered table-striped">
                                    <thead class="table-light">
                                        <tr>
                                            <th>批次号</th>
                                            <th>产品名称</th>
                                            <th>完成日期</th>
                                            <th>测试总数</th>
                                            <th>通过测试</th>
                                            <th>通过率</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if (!empty($quality_data)): ?>
                                            <?php foreach ($quality_data as $item): ?>
                                                <?php
                                                $pass_rate = ($item['total_tests'] > 0) ? ($item['passed_tests'] / $item['total_tests'] * 100) : 0;
                                                ?>
                                                <tr>
                                                    <td><?= htmlspecialchars($item['batch_number']) ?></td>
                                                    <td><?= htmlspecialchars($item['product_name']) ?></td>
                                                    <td><?= $item['completion_date'] ?></td>
                                                    <td><?= number_format($item['total_tests']) ?></td>
                                                    <td><?= number_format($item['passed_tests']) ?></td>
                                                    <td><?= number_format($pass_rate, 2) ?>%</td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php else: ?>
                                            <tr>
                                                <td colspan="6" class="text-center">暂无质量检测数据</td>
                                            </tr>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>

                    <!-- 效率分析 -->
                    <div class="tab-pane fade" id="efficiency-tab-pane" role="tabpanel" aria-labelledby="efficiency-tab" tabindex="0">
                        <div class="mb-4">
                            <div class="table-responsive">
                                <table class="table table-bordered table-striped">
                                    <thead class="table-light">
                                        <tr>
                                            <th>批次号</th>
                                            <th>产品名称</th>
                                            <th>开始日期</th>
                                            <th>完成日期</th>
                                            <th>生产周期(天)</th>
                                            <th>计划数量</th>
                                            <th>实际数量</th>
                                            <th>完成率</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if (!empty($efficiency_data)): ?>
                                            <?php foreach ($efficiency_data as $item): ?>
                                                <tr>
                                                    <td><?= htmlspecialchars($item['batch_number']) ?></td>
                                                    <td><?= htmlspecialchars($item['product_name']) ?></td>
                                                    <td><?= $item['start_date'] ?></td>
                                                    <td><?= $item['completion_date'] ?></td>
                                                    <td><?= number_format($item['duration_days']) ?></td>
                                                    <td><?= number_format($item['planned_quantity']) ?></td>
                                                    <td><?= number_format($item['actual_quantity']) ?></td>
                                                    <td><?= number_format($item['completion_rate'], 2) ?>%</td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php else: ?>
                                            <tr>
                                                <td colspan="8" class="text-center">暂无生产效率数据</td>
                                            </tr>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                        <div class="mt-3 mb-5">
                            <h3>生产效率分析</h3>
                            <p>
                                该表格展示了各生产批次的详细信息，包括生产周期、计划数量、实际数量和完成率。通过分析生产周期和完成率，
                                可以评估生产效率，发现生产过程中的瓶颈，优化生产流程，提高生产效率。
                            </p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.bootcdn.net/ajax/libs/bootstrap/5.1.3/js/bootstrap.bundle.min.js"></script>
    <script>
        // 自定义日期范围切换
        function toggleCustomDate() {
            const dateRange = document.getElementById('date_range').value;
            const customDate = document.getElementById('custom_date');
            customDate.style.display = (dateRange === 'custom') ? 'block' : 'none';
        }

        // 初始化图表
        document.addEventListener('DOMContentLoaded', function() {
            // 生产趋势图
            var productionTrendChart = echarts.init(document.getElementById('productionTrendChart'));
            var productionTrendOption = {
                title: {
                    text: '生产趋势',
                    left: 'center'
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow'
                    }
                },
                legend: {
                    data: ['计划生产量', '实际生产量', '批次数'],
                    top: 30
                },
                grid: {
                    left: '3%',
                    right: '4%',
                    bottom: '3%',
                    containLabel: true
                },
                xAxis: {
                    type: 'category',
                    data: <?= json_encode($chart_labels) ?>
                },
                yAxis: [{
                        type: 'value',
                        name: '生产量',
                        axisLabel: {
                            formatter: '{value}'
                        }
                    },
                    {
                        type: 'value',
                        name: '批次数',
                        axisLabel: {
                            formatter: '{value}'
                        }
                    }
                ],
                series: [{
                        name: '计划生产量',
                        type: 'bar',
                        data: <?= json_encode($chart_planned) ?>,
                        itemStyle: {
                            color: '#2ecc71'
                        }
                    },
                    {
                        name: '实际生产量',
                        type: 'bar',
                        data: <?= json_encode($chart_actual) ?>,
                        itemStyle: {
                            color: '#3498db'
                        }
                    },
                    {
                        name: '批次数',
                        type: 'line',
                        yAxisIndex: 1,
                        data: <?= json_encode($chart_batches) ?>,
                        itemStyle: {
                            color: '#e74c3c'
                        }
                    }
                ]
            };
            productionTrendChart.setOption(productionTrendOption);

            // 产品饼图
            var productPieChart = echarts.init(document.getElementById('productPieChart'));
            var productPieOption = {
                title: {
                    text: '产品生产分布',
                    left: 'center'
                },
                tooltip: {
                    trigger: 'item',
                    formatter: '{a} <br/>{b}: {c} ({d}%)'
                },
                legend: {
                    orient: 'vertical',
                    left: 10,
                    top: 30,
                    data: <?= json_encode(array_column($product_data, 'product_name')) ?>
                },
                series: [{
                    name: '实际生产量',
                    type: 'pie',
                    radius: ['40%', '70%'],
                    avoidLabelOverlap: false,
                    itemStyle: {
                        borderRadius: 10,
                        borderColor: '#fff',
                        borderWidth: 2
                    },
                    label: {
                        show: false,
                        position: 'center'
                    },
                    emphasis: {
                        label: {
                            show: true,
                            fontSize: '15',
                            fontWeight: 'bold'
                        }
                    },
                    labelLine: {
                        show: false
                    },
                    data: [
                        <?php foreach ($product_data as $item): ?> {
                                value: <?= $item['actual_quantity'] ?>,
                                name: '<?= htmlspecialchars($item['product_name']) ?>'
                            },
                        <?php endforeach; ?>
                    ]
                }]
            };
            productPieChart.setOption(productPieOption);

            // 质量柱状图
            var qualityBarChart = echarts.init(document.getElementById('qualityBarChart'));
            var qualityBarOption = {
                title: {
                    text: '产品质量通过率',
                    left: 'center'
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow'
                    },
                    formatter: '{b}: {c}%'
                },
                grid: {
                    left: '3%',
                    right: '4%',
                    bottom: '3%',
                    containLabel: true
                },
                xAxis: {
                    type: 'category',
                    data: <?= json_encode($quality_labels) ?>,
                    axisLabel: {
                        interval: 0,
                        rotate: 30
                    }
                },
                yAxis: {
                    type: 'value',
                    min: 0,
                    max: 100,
                    axisLabel: {
                        formatter: '{value}%'
                    }
                },
                series: [{
                    name: '通过率',
                    type: 'bar',
                    data: <?= json_encode($quality_pass_rates) ?>,
                    itemStyle: {
                        color: function(params) {
                            var value = params.value;
                            if (value >= 90) {
                                return '#2ecc71'; // 绿色，优秀
                            } else if (value >= 80) {
                                return '#f1c40f'; // 黄色，良好
                            } else if (value >= 70) {
                                return '#e67e22'; // 橙色，一般
                            } else {
                                return '#e74c3c'; // 红色，差
                            }
                        }
                    },
                    label: {
                        show: true,
                        position: 'top',
                        formatter: '{c}%'
                    }
                }]
            };
            qualityBarChart.setOption(qualityBarOption);

            // 监听选项卡切换事件，重新渲染图表
            document.querySelectorAll('button[data-bs-toggle="tab"]').forEach(function(tabEl) {
                tabEl.addEventListener('shown.bs.tab', function(event) {
                    const targetTab = event.target.getAttribute('data-bs-target');
                    if (targetTab === '#trend-tab-pane') {
                        productionTrendChart.resize();
                    } else if (targetTab === '#product-tab-pane') {
                        productPieChart.resize();
                    } else if (targetTab === '#quality-tab-pane') {
                        qualityBarChart.resize();
                    }
                });
            });

            // 窗口大小变化时调整图表大小
            window.addEventListener('resize', function() {
                productionTrendChart.resize();
                productPieChart.resize();
                qualityBarChart.resize();
            });
        });
    </script>
</body>

</html>