<?php
// analytics/sales_analysis.php - 销售数据分析
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化筛选参数
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'year';
$sales_channel_id = isset($_GET['sales_channel_id']) ? intval($_GET['sales_channel_id']) : 0;

// 设置日期范围
switch ($date_range) {
    case 'week':
        $date_from = date('Y-m-d', strtotime('-1 week'));
        $date_to = date('Y-m-d');
        break;
    case 'month':
        $date_from = date('Y-m-d', strtotime('-1 month'));
        $date_to = date('Y-m-d');
        break;
    case 'quarter':
        $date_from = date('Y-m-d', strtotime('-3 month'));
        $date_to = date('Y-m-d');
        break;
    case 'year':
        $date_from = date('Y-m-d', strtotime('-1 year'));
        $date_to = date('Y-m-d');
        break;
    case 'custom':
        $date_from = isset($_GET['date_from']) ? $_GET['date_from'] : date('Y-m-d', strtotime('-1 month'));
        $date_to = isset($_GET['date_to']) ? $_GET['date_to'] : date('Y-m-d');
        break;
    default:
        $date_from = date('Y-m-d', strtotime('-1 month'));
        $date_to = date('Y-m-d');
}

// 获取所有销售渠道
try {
    $stmt = $pdo->query("SELECT id, name FROM sales_channels ORDER BY name");
    $sales_channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取销售渠道失败: " . $e->getMessage();
}

// 获取销售总览数据
try {
    $sql = "
        SELECT 
            COUNT(*) AS total_orders,
            SUM(total_amount) AS total_sales,
            AVG(total_amount) AS avg_order_value,
            COUNT(DISTINCT customer_id) AS customer_count
        FROM 
            sales_orders
        WHERE 
            order_date BETWEEN ? AND ?
            AND status != 'cancelled'
    ";

    $params = [$date_from, $date_to];

    if ($sales_channel_id > 0) {
        $sql .= " AND sales_channel_id = ?";
        $params[] = $sales_channel_id;
    }

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $sales_overview = $stmt->fetch();
} catch (PDOException $e) {
    $error = "获取销售总览数据失败: " . $e->getMessage();
}

// 获取时间序列销售数据
try {
    // 根据选择的时间范围确定分组方式
    switch ($date_range) {
        case 'week':
            $group_by = "DATE(order_date)";
            $format = "%Y-%m-%d";
            $label = "日期";
            break;
        case 'month':
        case 'quarter':
            $group_by = "DATE(order_date)";
            $format = "%Y-%m-%d";
            $label = "日期";
            break;
        case 'year':
            $group_by = "DATE_FORMAT(order_date, '%Y-%m')";
            $format = "%Y-%m";
            $label = "月份";
            break;
        default:
            $group_by = "DATE(order_date)";
            $format = "%Y-%m-%d";
            $label = "日期";
    }

    $sql = "
        SELECT 
            DATE_FORMAT(order_date, '$format') AS time_period,
            COUNT(*) AS order_count,
            SUM(total_amount) AS sales_amount
        FROM 
            sales_orders
        WHERE 
            order_date BETWEEN ? AND ?
            AND status != 'cancelled'
    ";

    $params = [$date_from, $date_to];

    if ($sales_channel_id > 0) {
        $sql .= " AND sales_channel_id = ?";
        $params[] = $sales_channel_id;
    }

    $sql .= " GROUP BY DATE_FORMAT(order_date, '$format') ORDER BY time_period";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $time_series_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取时间序列销售数据失败: " . $e->getMessage();
}

// 获取销售渠道分布
try {
    $sql = "
        SELECT 
            sc.name AS channel_name,
            COUNT(so.id) AS order_count,
            SUM(so.total_amount) AS total_amount
        FROM 
            sales_orders so
        JOIN 
            sales_channels sc ON so.sales_channel_id = sc.id
        WHERE 
            so.order_date BETWEEN ? AND ?
            AND so.status != 'cancelled'
        GROUP BY 
            sc.name, so.sales_channel_id
        ORDER BY 
            total_amount DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute([$date_from, $date_to]);
    $channel_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取销售渠道分布失败: " . $e->getMessage();
}

// 获取区域销售分布
try {
    $sql = "
        SELECT 
            c.region,
            COUNT(so.id) AS order_count,
            SUM(so.total_amount) AS total_amount
        FROM 
            sales_orders so
        JOIN 
            customers c ON so.customer_id = c.id
        WHERE 
            so.order_date BETWEEN ? AND ?
            AND so.status != 'cancelled'
            AND c.region IS NOT NULL
            AND c.region != ''
        GROUP BY 
            c.region
        ORDER BY 
            total_amount DESC
    ";

    $params = [$date_from, $date_to];

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $region_data = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取区域销售数据失败: " . $e->getMessage();
}

// 获取产品销量排行
try {
    $query = "
        SELECT 
            p.id,
            p.name AS product_name,
            SUM(soi.quantity) AS total_quantity,
            SUM(soi.item_total_amount) AS total_amount
        FROM 
            sales_order_items soi
        JOIN 
            products p ON soi.product_id = p.id
        JOIN 
            sales_orders so ON soi.sales_order_id = so.id
        WHERE 
            so.order_date BETWEEN ? AND ?
    ";

    $params = [$date_from . ' 00:00:00', $date_to . ' 23:59:59'];

    if ($sales_channel_id > 0) {
        $query .= " AND so.sales_channel_id = ?";
        $params[] = $sales_channel_id;
    }

    $query .= " GROUP BY p.id, p.name ORDER BY total_amount DESC LIMIT 10";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $product_ranking = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取产品销量排行数据失败: " . $e->getMessage();
    $product_ranking = []; // 确保失败时是空数组
}

// 准备图表数据
$chart_labels = [];
$chart_sales = [];
$chart_orders = [];

if (!empty($time_series_data)) {
    foreach ($time_series_data as $item) {
        $chart_labels[] = $item['time_period'];
        $chart_sales[] = $item['sales_amount'];
        $chart_orders[] = $item['order_count'];
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>销售数据分析 - <?= title ?></title>
    <link rel="stylesheet" href="https://cdn.bootcdn.net/ajax/libs/bootstrap/5.1.3/css/bootstrap.min.css">
    <script src="https://cdn.bootcdn.net/ajax/libs/echarts/5.3.3/echarts.min.js"></script>
    <style>
        .card {
            margin-bottom: 20px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .chart-container {
            height: 400px;
            margin-bottom: 20px;
        }

        .stat-card {
            text-align: center;
            padding: 20px;
            background: linear-gradient(135deg, #3498db, #2c3e50);
            color: white;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }

        .stat-card h2 {
            font-size: 24px;
            margin-bottom: 10px;
        }

        .stat-card p {
            font-size: 28px;
            font-weight: bold;
            margin: 0;
        }

        .stat-card small {
            font-size: 14px;
            opacity: 0.8;
        }

        .nav-pills .nav-link.active {
            background-color: #3498db;
        }
    </style>
</head>

<body class="bg-light">
    <div class="container-fluid py-4">
        <h1 class="mb-4">销售数据分析</h1>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <!-- 筛选器 -->
        <div class="card mb-4">
            <div class="card-body">
                <form method="get" class="row">
                    <div class="col-md-3 mb-3">
                        <label for="date_range" class="form-label">时间范围</label>
                        <select id="date_range" name="date_range" class="form-select" onchange="toggleCustomDate()">
                            <option value="week" <?= $date_range == 'week' ? 'selected' : '' ?>>最近一周</option>
                            <option value="month" <?= $date_range == 'month' ? 'selected' : '' ?>>最近一个月</option>
                            <option value="quarter" <?= $date_range == 'quarter' ? 'selected' : '' ?>>最近一个季度</option>
                            <option value="year" <?= $date_range == 'year' ? 'selected' : '' ?>>最近一年</option>
                            <option value="custom" <?= $date_range == 'custom' ? 'selected' : '' ?>>自定义</option>
                        </select>
                    </div>

                    <div id="custom_date" class="col-md-4 mb-3" style="display: <?= $date_range == 'custom' ? 'block' : 'none' ?>">
                        <div class="row">
                            <div class="col-6">
                                <label for="date_from" class="form-label">开始日期</label>
                                <input type="date" id="date_from" name="date_from" class="form-control" value="<?= $date_from ?>">
                            </div>
                            <div class="col-6">
                                <label for="date_to" class="form-label">结束日期</label>
                                <input type="date" id="date_to" name="date_to" class="form-control" value="<?= $date_to ?>">
                            </div>
                        </div>
                    </div>

                    <div class="col-md-3 mb-3">
                        <label for="sales_channel_id" class="form-label">销售渠道</label>
                        <select id="sales_channel_id" name="sales_channel_id" class="form-select">
                            <option value="0">所有渠道</option>
                            <?php foreach ($sales_channels as $channel): ?>
                                <option value="<?= $channel['id'] ?>" <?= $sales_channel_id == $channel['id'] ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($channel['name']) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="col-md-2 mb-3 d-flex align-items-end">
                        <button type="submit" class="btn btn-primary w-100">应用筛选</button>
                    </div>
                </form>
            </div>
        </div>

        <!-- 销售统计卡片 -->
        <div class="row mb-4">
            <div class="col-md-3">
                <div class="stat-card">
                    <h2>销售总额</h2>
                    <p>¥<?= number_format($sales_overview['total_sales'] ?? 0, 2) ?></p>
                    <small>所选时间段内的总销售额</small>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stat-card">
                    <h2>订单总数</h2>
                    <p><?= number_format($sales_overview['total_orders'] ?? 0) ?></p>
                    <small>所选时间段内的订单总数</small>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stat-card">
                    <h2>平均订单金额</h2>
                    <p>¥<?= number_format($sales_overview['avg_order_value'] ?? 0, 2) ?></p>
                    <small>所选时间段内的平均订单金额</small>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stat-card">
                    <h2>客户数量</h2>
                    <p><?= number_format($sales_overview['customer_count'] ?? 0) ?></p>
                    <small>所选时间段内的下单客户数</small>
                </div>
            </div>
        </div>

        <!-- 分析内容 -->
        <div class="card">
            <div class="card-header">
                <ul class="nav nav-pills" id="salesTab" role="tablist">
                    <li class="nav-item" role="presentation">
                        <button class="nav-link active" id="trend-tab" data-bs-toggle="tab" data-bs-target="#trend-tab-pane" type="button" role="tab">销售趋势</button>
                    </li>
                    <li class="nav-item" role="presentation">
                        <button class="nav-link" id="channel-tab" data-bs-toggle="tab" data-bs-target="#channel-tab-pane" type="button" role="tab">渠道分析</button>
                    </li>
                    <li class="nav-item" role="presentation">
                        <button class="nav-link" id="region-tab" data-bs-toggle="tab" data-bs-target="#region-tab-pane" type="button" role="tab">区域分析</button>
                    </li>
                    <li class="nav-item" role="presentation">
                        <button class="nav-link" id="product-tab" data-bs-toggle="tab" data-bs-target="#product-tab-pane" type="button" role="tab">产品排行</button>
                    </li>
                </ul>
            </div>
            <div class="card-body">
                <div class="tab-content" id="salesTabContent">
                    <!-- 销售趋势 -->
                    <div class="tab-pane fade show active" id="trend-tab-pane" role="tabpanel" aria-labelledby="trend-tab" tabindex="0">
                        <div class="chart-container">
                            <div id="salesTrendChart" style="width: 100%; height: 100%;"></div>
                        </div>
                        <div class="mt-3 mb-5">
                            <h3>销售趋势分析</h3>
                            <p>
                                该图表显示了所选时间段内的销售金额和订单数量的变化趋势。通过观察趋势，可以识别销售高峰和低谷，
                                帮助制定营销策略和库存管理计划。同时，销售金额与订单数量的对比可以反映客单价的变化，为定价策略提供参考。
                            </p>
                        </div>
                    </div>

                    <!-- 渠道分析 -->
                    <div class="tab-pane fade" id="channel-tab-pane" role="tabpanel" aria-labelledby="channel-tab" tabindex="0">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="chart-container">
                                    <div id="channelPieChart" style="width: 100%; height: 100%;"></div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="table-responsive">
                                    <table class="table table-bordered table-striped">
                                        <thead class="table-light">
                                            <tr>
                                                <th>销售渠道</th>
                                                <th>订单数量</th>
                                                <th>销售金额</th>
                                                <th>占比</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php
                                            $total_channel_amount = array_sum(array_column($channel_data, 'total_amount'));
                                            foreach ($channel_data as $item):
                                            ?>
                                                <tr>
                                                    <td><?= htmlspecialchars($item['channel_name']) ?></td>
                                                    <td><?= number_format($item['order_count']) ?></td>
                                                    <td>¥<?= number_format($item['total_amount'], 2) ?></td>
                                                    <td><?= number_format(($item['total_amount'] / $total_channel_amount) * 100, 2) ?>%</td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                        </div>
                        <div class="mt-3 mb-5">
                            <h3>销售渠道分析</h3>
                            <p>
                                该图表和表格展示了不同销售渠道的销售金额和占比情况。通过分析各渠道的销售表现，
                                可以确定重点发展的渠道，优化资源分配，制定针对性的营销策略，提高整体销售效率。
                            </p>
                        </div>
                    </div>

                    <!-- 区域分析 -->
                    <div class="tab-pane fade" id="region-tab-pane" role="tabpanel" aria-labelledby="region-tab" tabindex="0">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="chart-container">
                                    <div id="regionBarChart" style="width: 100%; height: 100%;"></div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="table-responsive">
                                    <table class="table table-bordered table-striped">
                                        <thead class="table-light">
                                            <tr>
                                                <th>区域</th>
                                                <th>订单数量</th>
                                                <th>销售金额</th>
                                                <th>占比</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php
                                            $total_region_amount = array_sum(array_column($region_data, 'total_amount'));
                                            foreach ($region_data as $item):
                                            ?>
                                                <tr>
                                                    <td><?= htmlspecialchars($item['region']) ?></td>
                                                    <td><?= number_format($item['order_count']) ?></td>
                                                    <td>¥<?= number_format($item['total_amount'], 2) ?></td>
                                                    <td><?= number_format(($item['total_amount'] / $total_region_amount) * 100, 2) ?>%</td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                        </div>
                        <div class="mt-3 mb-5">
                            <h3>区域销售分析</h3>
                            <p>
                                该图表和表格展示了不同区域的销售情况。通过区域分析，可以发现市场潜力大的区域，合理规划物流配送，
                                制定区域营销策略，提高区域市场占有率，同时也为拓展新区域市场提供参考依据。
                            </p>
                        </div>
                    </div>

                    <!-- 产品排行 -->
                    <div class="tab-pane fade" id="product-tab-pane" role="tabpanel" aria-labelledby="product-tab" tabindex="0">
                        <div class="chart-container">
                            <div id="productRankingChart" style="width: 100%; height: 100%;"></div>
                        </div>
                        <div class="mt-3">
                            <div class="table-responsive">
                                <table class="table table-bordered table-striped">
                                    <thead class="table-light">
                                        <tr>
                                            <th>排名</th>
                                            <th>产品名称</th>
                                            <th>销售数量</th>
                                            <th>销售金额</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($product_ranking as $index => $item): ?>
                                            <tr>
                                                <td><?= $index + 1 ?></td>
                                                <td><?= htmlspecialchars($item['product_name']) ?></td>
                                                <td><?= number_format($item['total_quantity']) ?></td>
                                                <td>¥<?= number_format($item['total_amount'], 2) ?></td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.bootcdn.net/ajax/libs/bootstrap/5.1.3/js/bootstrap.bundle.min.js"></script>
    <script>
        // 自定义日期范围切换
        function toggleCustomDate() {
            const dateRange = document.getElementById('date_range').value;
            const customDate = document.getElementById('custom_date');
            customDate.style.display = (dateRange === 'custom') ? 'block' : 'none';
        }

        // 初始化图表
        document.addEventListener('DOMContentLoaded', function() {
            // 销售趋势图
            var salesTrendChart = echarts.init(document.getElementById('salesTrendChart'));
            var salesTrendOption = {
                title: {
                    text: '销售趋势',
                    left: 'center'
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow'
                    }
                },
                legend: {
                    data: ['销售金额', '订单数量'],
                    top: 30
                },
                grid: {
                    left: '3%',
                    right: '4%',
                    bottom: '3%',
                    containLabel: true
                },
                xAxis: {
                    type: 'category',
                    data: <?= json_encode($chart_labels) ?>
                },
                yAxis: [{
                        type: 'value',
                        name: '销售金额',
                        axisLabel: {
                            formatter: '¥{value}'
                        }
                    },
                    {
                        type: 'value',
                        name: '订单数量',
                        axisLabel: {
                            formatter: '{value}'
                        }
                    }
                ],
                series: [{
                        name: '销售金额',
                        type: 'bar',
                        data: <?= json_encode($chart_sales) ?>,
                        itemStyle: {
                            color: '#3498db'
                        }
                    },
                    {
                        name: '订单数量',
                        type: 'line',
                        yAxisIndex: 1,
                        data: <?= json_encode($chart_orders) ?>,
                        itemStyle: {
                            color: '#e74c3c'
                        }
                    }
                ]
            };
            salesTrendChart.setOption(salesTrendOption);

            // 渠道饼图
            var channelPieChart = echarts.init(document.getElementById('channelPieChart'));
            var channelPieOption = {
                title: {
                    text: '销售渠道分布',
                    left: 'center'
                },
                tooltip: {
                    trigger: 'item',
                    formatter: '{a} <br/>{b}: {c} ({d}%)'
                },
                legend: {
                    orient: 'vertical',
                    left: 10,
                    top: 30,
                    data: <?= json_encode(array_column($channel_data, 'channel_name')) ?>
                },
                series: [{
                    name: '销售金额',
                    type: 'pie',
                    radius: ['40%', '70%'],
                    avoidLabelOverlap: false,
                    itemStyle: {
                        borderRadius: 10,
                        borderColor: '#fff',
                        borderWidth: 2
                    },
                    label: {
                        show: false,
                        position: 'center'
                    },
                    emphasis: {
                        label: {
                            show: true,
                            fontSize: '15',
                            fontWeight: 'bold'
                        }
                    },
                    labelLine: {
                        show: false
                    },
                    data: [
                        <?php foreach ($channel_data as $item): ?> {
                                value: <?= $item['total_amount'] ?>,
                                name: '<?= htmlspecialchars($item['channel_name']) ?>'
                            },
                        <?php endforeach; ?>
                    ]
                }]
            };
            channelPieChart.setOption(channelPieOption);

            // 区域柱状图
            var regionBarChart = echarts.init(document.getElementById('regionBarChart'));
            var regionData = [];
            <?php foreach ($region_data as $item): ?>
                regionData.push({
                    value: <?= $item['total_amount'] ?>,
                    name: '<?= htmlspecialchars($item['region']) ?>'
                });
            <?php endforeach; ?>
            regionData.sort(function(a, b) {
                return b.value - a.value; // 降序排列
            });

            var regionBarOption = {
                title: {
                    text: '区域销售分布',
                    left: 'center'
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow'
                    },
                    formatter: '{b}: ¥{c}'
                },
                grid: {
                    left: '3%',
                    right: '4%',
                    bottom: '3%',
                    containLabel: true
                },
                xAxis: {
                    type: 'value',
                    axisLabel: {
                        formatter: '¥{value}'
                    }
                },
                yAxis: {
                    type: 'category',
                    data: regionData.map(function(item) {
                        return item.name;
                    }),
                    axisLabel: {
                        interval: 0,
                        rotate: 30
                    }
                },
                series: [{
                    name: '销售金额',
                    type: 'bar',
                    data: regionData.map(function(item) {
                        return item.value;
                    }),
                    itemStyle: {
                        color: function(params) {
                            var colorList = ['#3498db', '#2ecc71', '#9b59b6', '#f1c40f', '#e74c3c', '#1abc9c', '#34495e', '#e67e22'];
                            return colorList[params.dataIndex % colorList.length];
                        }
                    }
                }]
            };
            regionBarChart.setOption(regionBarOption);

            // 产品排行图
            var productRankingChart = echarts.init(document.getElementById('productRankingChart'));
            var productData = [];
            <?php foreach ($product_ranking as $item): ?>
                productData.push({
                    value: <?= $item['total_amount'] ?>,
                    name: '<?= htmlspecialchars($item['product_name']) ?>'
                });
            <?php endforeach; ?>
            productData.sort(function(a, b) {
                return b.value - a.value; // 降序排列
            });

            var productRankingOption = {
                title: {
                    text: '产品销售排行',
                    left: 'center'
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow'
                    },
                    formatter: '{b}: ¥{c}'
                },
                grid: {
                    left: '3%',
                    right: '4%',
                    bottom: '3%',
                    containLabel: true
                },
                xAxis: {
                    type: 'value',
                    axisLabel: {
                        formatter: '¥{value}'
                    }
                },
                yAxis: {
                    type: 'category',
                    data: productData.map(function(item) {
                        return item.name;
                    }),
                    axisLabel: {
                        interval: 0,
                        rotate: 30
                    }
                },
                series: [{
                    name: '销售金额',
                    type: 'bar',
                    data: productData.map(function(item) {
                        return item.value;
                    }),
                    itemStyle: {
                        color: function(params) {
                            var colorList = ['#3498db', '#2ecc71', '#9b59b6', '#f1c40f', '#e74c3c', '#1abc9c', '#34495e', '#e67e22'];
                            return colorList[params.dataIndex % colorList.length];
                        }
                    }
                }]
            };
            productRankingChart.setOption(productRankingOption);

            // 监听选项卡切换事件，重新渲染图表
            document.querySelectorAll('button[data-bs-toggle="tab"]').forEach(function(tabEl) {
                tabEl.addEventListener('shown.bs.tab', function(event) {
                    const targetTab = event.target.getAttribute('data-bs-target');
                    if (targetTab === '#trend-tab-pane') {
                        salesTrendChart.resize();
                    } else if (targetTab === '#channel-tab-pane') {
                        channelPieChart.resize();
                    } else if (targetTab === '#region-tab-pane') {
                        regionBarChart.resize();
                    } else if (targetTab === '#product-tab-pane') {
                        productRankingChart.resize();
                    }
                });
            });

            // 窗口大小变化时调整图表大小
            window.addEventListener('resize', function() {
                salesTrendChart.resize();
                channelPieChart.resize();
                regionBarChart.resize();
                productRankingChart.resize();
            });
        });
    </script>
</body>

</html>