<?php

/**
 * 客户反馈管理
 * 用于处理客户投诉、建议和满意度调查等反馈
 */

session_start();
require_once '../config.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../login.php');
    exit;
}

// 设置页面标题
$page_title = "客户反馈管理";

// 初始化变量
$success = '';
$error = '';

// 获取筛选参数
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$customer_id = isset($_GET['customer_id']) ? intval($_GET['customer_id']) : 0;
$type = isset($_GET['type']) ? $_GET['type'] : '';
$status = isset($_GET['status']) ? $_GET['status'] : '';
$priority = isset($_GET['priority']) ? $_GET['priority'] : '';

// 创建客户反馈表
try {
    // 检查客户反馈表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'customer_feedback'");
    if (!$stmt->rowCount()) {
        // 创建客户反馈表
        $pdo->exec("
            CREATE TABLE `customer_feedback` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '反馈ID',
              `customer_id` INT UNSIGNED NOT NULL COMMENT '客户ID',
              `type` ENUM('complaint', 'suggestion', 'praise', 'return_request', 'survey') NOT NULL COMMENT '反馈类型',
              `subject` VARCHAR(255) NOT NULL COMMENT '主题',
              `content` TEXT NOT NULL COMMENT '内容',
              `priority` ENUM('low', 'medium', 'high', 'urgent') NOT NULL DEFAULT 'medium' COMMENT '优先级',
              `status` ENUM('new', 'in_progress', 'resolved', 'closed') NOT NULL DEFAULT 'new' COMMENT '状态',
              `response` TEXT DEFAULT NULL COMMENT '回复内容',
              `response_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '回复人ID',
              `response_at` DATETIME DEFAULT NULL COMMENT '回复时间',
              `satisfaction_rating` TINYINT UNSIGNED DEFAULT NULL COMMENT '满意度评分(1-5)',
              `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
              PRIMARY KEY (`id`),
              KEY `idx_feedback_customer` (`customer_id`),
              KEY `idx_feedback_type` (`type`),
              KEY `idx_feedback_status` (`status`),
              KEY `idx_feedback_priority` (`priority`)
            ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '客户反馈表'
        ");

        // 插入示例数据
        $pdo->exec("
            INSERT INTO
              `customer_feedback` (
                `customer_id`,
                `type`,
                `subject`,
                `content`,
                `priority`,
                `status`,
                `created_at`
              )
            VALUES
              (
                1,
                'complaint',
                '上次订单产品包装损坏',
                '我在2024年3月15日收到的订单中，有两件产品的包装已经破损，产品本身也有轻微碰撞痕迹。希望能够给予处理。',
                'high',
                'in_progress',
                '2024-03-16 10:23:45'
              ),
              (
                2,
                'suggestion',
                '建议增加新口味产品',
                '我是贵公司的忠实客户，我建议推出一些新的口味，比如酸辣口味的系列产品，相信会受到年轻消费者的欢迎。',
                'medium',
                'new',
                '2024-03-20 14:35:12'
              ),
              (
                3,
                'praise',
                '对客服服务的赞扬',
                '我想表扬一下你们的客服团队，尤其是小王，他处理我的问题非常耐心和专业，解决了我的所有疑问。',
                'low',
                'closed',
                '2024-03-10 09:15:30'
              )
        ");
        $success = "已创建客户反馈表并插入示例数据";
    }

    // 处理添加/编辑客户反馈表单提交
    if (isset($_POST['save_feedback'])) {
        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
        $customer_id = intval($_POST['customer_id']);
        $type = $_POST['type'];
        $subject = trim($_POST['subject']);
        $content = trim($_POST['content']);
        $priority = $_POST['priority'];
        $status = $_POST['status'];
        $response = isset($_POST['response']) ? trim($_POST['response']) : null;

        // 验证必填字段
        if (empty($customer_id) || empty($type) || empty($subject) || empty($content)) {
            $error = "客户、反馈类型、主题和内容为必填项！";
        } else {
            try {
                if ($id > 0) {
                    // 更新客户反馈
                    $sql = "
                        UPDATE customer_feedback SET 
                            customer_id = ?, 
                            type = ?, 
                            subject = ?, 
                            content = ?, 
                            priority = ?, 
                            status = ?
                    ";

                    $params = [
                        $customer_id,
                        $type,
                        $subject,
                        $content,
                        $priority,
                        $status
                    ];

                    // 如果有回复内容
                    if (!empty($response)) {
                        $sql .= ", response = ?, response_by_user_id = ?, response_at = NOW()";
                        $params[] = $response;
                        $params[] = $_SESSION['user_id'];
                    }

                    $sql .= " WHERE id = ?";
                    $params[] = $id;

                    $stmt = $pdo->prepare($sql);
                    $stmt->execute($params);

                    $success = "客户反馈已更新！";
                } else {
                    // 添加新客户反馈
                    $stmt = $pdo->prepare("
                        INSERT INTO customer_feedback (
                            customer_id, 
                            type, 
                            subject, 
                            content, 
                            priority, 
                            status
                        ) VALUES (?, ?, ?, ?, ?, ?)
                    ");
                    $stmt->execute([
                        $customer_id,
                        $type,
                        $subject,
                        $content,
                        $priority,
                        $status
                    ]);
                    $success = "客户反馈已成功添加！";
                }

                // 记录操作日志
                if (isset($_SESSION['user_id']) && isset($_SESSION['username'])) {
                    $action = $id > 0 ? '更新客户反馈' : '创建客户反馈';
                    $details = json_encode([
                        'id' => $id > 0 ? $id : $pdo->lastInsertId(),
                        'type' => $type,
                        'subject' => $subject
                    ]);

                    $stmt = $pdo->prepare("
                        INSERT INTO activity_log (
                            user_id, 
                            username, 
                            action, 
                            target_type, 
                            target_id, 
                            details, 
                            ip_address
                        ) VALUES (?, ?, ?, ?, ?, ?, ?)
                    ");
                    $stmt->execute([
                        $_SESSION['user_id'],
                        $_SESSION['username'],
                        $action,
                        'customer_feedback',
                        $id > 0 ? $id : $pdo->lastInsertId(),
                        $details,
                        $_SERVER['REMOTE_ADDR']
                    ]);
                }
            } catch (PDOException $e) {
                $error = "保存客户反馈失败：" . $e->getMessage();
            }
        }
    }

    // 获取所有客户列表（用于筛选和表单选择）
    $customers = $pdo->query("SELECT id, name FROM customers WHERE is_active = 1 ORDER BY name")->fetchAll(PDO::FETCH_ASSOC);

    // 构建查询
    $sql = "
        SELECT 
            f.*,
            c.name AS customer_name,
            c.type AS customer_type,
            u.username AS response_by_username
        FROM 
            customer_feedback f
        JOIN 
            customers c ON f.customer_id = c.id
        LEFT JOIN
            users u ON f.response_by_user_id = u.id
        WHERE 1=1
    ";
    $params = [];

    if (!empty($search)) {
        $sql .= " AND (f.subject LIKE ? OR f.content LIKE ? OR c.name LIKE ?)";
        $search_param = "%$search%";
        $params[] = $search_param;
        $params[] = $search_param;
        $params[] = $search_param;
    }

    if ($customer_id > 0) {
        $sql .= " AND f.customer_id = ?";
        $params[] = $customer_id;
    }

    if (!empty($type)) {
        $sql .= " AND f.type = ?";
        $params[] = $type;
    }

    if (!empty($status)) {
        $sql .= " AND f.status = ?";
        $params[] = $status;
    }

    if (!empty($priority)) {
        $sql .= " AND f.priority = ?";
        $params[] = $priority;
    }

    $sql .= " ORDER BY 
        CASE f.priority 
            WHEN 'urgent' THEN 1 
            WHEN 'high' THEN 2 
            WHEN 'medium' THEN 3 
            WHEN 'low' THEN 4 
        END,
        f.created_at DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $feedbacks = $stmt->fetchAll();

    // 获取要编辑的客户反馈信息
    $edit_data = null;
    if (isset($_GET['edit']) && $_GET['edit'] > 0) {
        $edit_id = intval($_GET['edit']);
        $stmt = $pdo->prepare("
            SELECT 
                f.*,
                c.name AS customer_name
            FROM 
                customer_feedback f
            JOIN 
                customers c ON f.customer_id = c.id
            WHERE 
                f.id = ?
        ");
        $stmt->execute([$edit_id]);
        $edit_data = $stmt->fetch();
    }

    // 反馈类型映射
    $feedback_types = [
        'complaint' => '投诉',
        'suggestion' => '建议',
        'praise' => '表扬',
        'return_request' => '退货请求',
        'survey' => '调查反馈'
    ];

    // 优先级映射
    $priorities = [
        'low' => '低',
        'medium' => '中',
        'high' => '高',
        'urgent' => '紧急'
    ];

    // 状态映射
    $statuses = [
        'new' => '新建',
        'in_progress' => '处理中',
        'resolved' => '已解决',
        'closed' => '已关闭'
    ];
} catch (PDOException $e) {
    $error = "数据库错误：" . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= htmlspecialchars($page_title) ?> - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="content">
        <h1><?= htmlspecialchars($page_title) ?></h1>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <!-- 筛选与搜索 -->
        <div class="filter-container">
            <form action="" method="GET" class="search-bar">
                <input type="text" name="search" placeholder="搜索主题、内容或客户名称..." value="<?= htmlspecialchars($search) ?>">

                <select name="customer_id" title="客户">
                    <option value="0">所有客户</option>
                    <?php foreach ($customers as $customer): ?>
                        <option value="<?= $customer['id'] ?>" <?= $customer_id === $customer['id'] ? 'selected' : '' ?>>
                            <?= htmlspecialchars($customer['name']) ?>
                        </option>
                    <?php endforeach; ?>
                </select>

                <select name="type" title="反馈类型">
                    <option value="">所有类型</option>
                    <?php foreach ($feedback_types as $key => $value): ?>
                        <option value="<?= $key ?>" <?= $type === $key ? 'selected' : '' ?>><?= $value ?></option>
                    <?php endforeach; ?>
                </select>

                <select name="status" title="处理状态">
                    <option value="">所有状态</option>
                    <?php foreach ($statuses as $key => $value): ?>
                        <option value="<?= $key ?>" <?= $status === $key ? 'selected' : '' ?>><?= $value ?></option>
                    <?php endforeach; ?>
                </select>

                <select name="priority" title="优先级">
                    <option value="">所有优先级</option>
                    <?php foreach ($priorities as $key => $value): ?>
                        <option value="<?= $key ?>" <?= $priority === $key ? 'selected' : '' ?>><?= $value ?></option>
                    <?php endforeach; ?>
                </select>

                <button type="submit">搜索</button>
                <button type="button" onclick="location.href='customer_feedback.php'" class="btn-secondary">重置</button>
            </form>
        </div>

        <!-- 添加/编辑客户反馈表单 -->
        <div class="form-container">
            <h2><?= $edit_data ? '编辑客户反馈' : '添加新客户反馈' ?></h2>
            <form method="POST" action="">
                <?php if ($edit_data): ?>
                    <input type="hidden" name="id" value="<?= $edit_data['id'] ?>">
                <?php endif; ?>

                <div class="form-row">
                    <div class="form-group">
                        <label for="customer_id">客户 <span class="required">*</span></label>
                        <select id="customer_id" name="customer_id" required>
                            <option value="">-- 请选择客户 --</option>
                            <?php foreach ($customers as $customer): ?>
                                <option value="<?= $customer['id'] ?>" <?= $edit_data && $edit_data['customer_id'] == $customer['id'] ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($customer['name']) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="type">反馈类型 <span class="required">*</span></label>
                        <select id="type" name="type" required>
                            <option value="">-- 请选择类型 --</option>
                            <?php foreach ($feedback_types as $key => $value): ?>
                                <option value="<?= $key ?>" <?= $edit_data && $edit_data['type'] === $key ? 'selected' : '' ?>><?= $value ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>

                <div class="form-group">
                    <label for="subject">主题 <span class="required">*</span></label>
                    <input type="text" id="subject" name="subject" value="<?= $edit_data ? htmlspecialchars($edit_data['subject']) : '' ?>" required>
                </div>

                <div class="form-group">
                    <label for="content">内容 <span class="required">*</span></label>
                    <textarea id="content" name="content" rows="4" required><?= $edit_data ? htmlspecialchars($edit_data['content']) : '' ?></textarea>
                </div>

                <div class="form-row">
                    <div class="form-group">
                        <label for="priority">优先级 <span class="required">*</span></label>
                        <select id="priority" name="priority" required>
                            <?php foreach ($priorities as $key => $value): ?>
                                <option value="<?= $key ?>" <?= $edit_data ? ($edit_data['priority'] === $key ? 'selected' : '') : ($key === 'medium' ? 'selected' : '') ?>><?= $value ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="status">状态 <span class="required">*</span></label>
                        <select id="status" name="status" required>
                            <?php foreach ($statuses as $key => $value): ?>
                                <option value="<?= $key ?>" <?= $edit_data ? ($edit_data['status'] === $key ? 'selected' : '') : ($key === 'new' ? 'selected' : '') ?>><?= $value ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>

                <?php if ($edit_data): ?>
                    <div class="form-group">
                        <label for="response">回复内容</label>
                        <textarea id="response" name="response" rows="4"><?= $edit_data ? htmlspecialchars($edit_data['response']) : '' ?></textarea>
                    </div>
                <?php endif; ?>

                <div class="form-actions">
                    <button type="submit" name="save_feedback" class="btn-primary"><?= $edit_data ? '更新反馈' : '添加反馈' ?></button>
                    <?php if ($edit_data): ?>
                        <button type="button" onclick="location.href='customer_feedback.php'" class="btn-secondary">取消</button>
                    <?php endif; ?>
                </div>
            </form>
        </div>

        <!-- 客户反馈列表 -->
        <div class="table-container">
            <h2>客户反馈列表</h2>
            <?php if (empty($feedbacks)): ?>
                <div class="empty-state">
                    <p>暂无客户反馈数据</p>
                </div>
            <?php else: ?>
                <table>
                    <thead>
                        <tr>
                            <th>客户</th>
                            <th>类型</th>
                            <th>主题</th>
                            <th>优先级</th>
                            <th>状态</th>
                            <th>提交时间</th>
                            <th>回复状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($feedbacks as $feedback): ?>
                            <tr class="<?= $feedback['priority'] === 'urgent' ? 'urgent-row' : ($feedback['priority'] === 'high' ? 'high-priority-row' : '') ?>">
                                <td><?= htmlspecialchars($feedback['customer_name']) ?></td>
                                <td><?= isset($feedback_types[$feedback['type']]) ? $feedback_types[$feedback['type']] : $feedback['type'] ?></td>
                                <td><?= htmlspecialchars($feedback['subject']) ?></td>
                                <td>
                                    <span class="priority-tag <?= $feedback['priority'] ?>">
                                        <?= $priorities[$feedback['priority']] ?>
                                    </span>
                                </td>
                                <td>
                                    <span class="status-tag <?= $feedback['status'] ?>">
                                        <?= $statuses[$feedback['status']] ?>
                                    </span>
                                </td>
                                <td><?= date('Y-m-d H:i', strtotime($feedback['created_at'])) ?></td>
                                <td><?= $feedback['response'] ? '已回复' : '未回复' ?></td>
                                <td>
                                    <a href="?edit=<?= $feedback['id'] ?>" class="btn-edit">处理</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php endif; ?>
        </div>
    </div>

    <style>
        /* 补充样式 */
        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .form-row {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 20px;
        }

        .search-bar {
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            align-items: center;
        }

        .search-bar input,
        .search-bar select {
            padding: 8px 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            flex: 1;
        }

        .search-bar button {
            padding: 8px 16px;
            border: none;
            border-radius: 4px;
            background-color: #3498db;
            color: white;
            cursor: pointer;
        }

        .search-bar button.btn-secondary {
            background-color: #6c757d;
        }

        textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            resize: vertical;
        }

        .form-actions {
            display: flex;
            justify-content: flex-start;
            gap: 10px;
            margin-top: 20px;
        }

        .required {
            color: #e74c3c;
        }

        .status-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 3px;
            font-size: 0.85em;
            font-weight: 500;
            color: white;
        }

        .status-tag.new {
            background-color: #3498db;
        }

        .status-tag.in_progress {
            background-color: #f39c12;
        }

        .status-tag.resolved {
            background-color: #2ecc71;
        }

        .status-tag.closed {
            background-color: #7f8c8d;
        }

        .priority-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 3px;
            font-size: 0.85em;
            font-weight: 500;
            color: white;
        }

        .priority-tag.low {
            background-color: #7f8c8d;
        }

        .priority-tag.medium {
            background-color: #3498db;
        }

        .priority-tag.high {
            background-color: #f39c12;
        }

        .priority-tag.urgent {
            background-color: #e74c3c;
        }

        .urgent-row {
            background-color: #fdedec !important;
        }

        .high-priority-row {
            background-color: #fef9e7 !important;
        }

        @media (max-width: 768px) {
            .form-row {
                grid-template-columns: 1fr;
                gap: 0;
            }

            .search-bar {
                flex-direction: column;
                align-items: stretch;
            }
        }
    </style>
</body>

</html>