<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取产品ID
$product_id = isset($_GET['product_id']) ? (int)$_GET['product_id'] : 0;

if ($product_id <= 0) {
    header("Location: finished_goods_inventory.php");
    exit;
}

$success_message = '';
$error_message = '';

// 获取产品信息和库存情况
try {
    $stmt = $pdo->prepare("
        SELECT 
            p.id AS product_id,
            p.name AS product_name,
            p.specification,
            i.id AS inventory_id,
            i.quantity_on_hand,
            i.unit,
            sl.id AS location_id,
            sl.name AS location_name
        FROM 
            products p
        JOIN 
            inventory i ON p.id = i.product_id
        JOIN 
            storage_locations sl ON i.storage_location_id = sl.id
        WHERE 
            p.id = ?
    ");
    $stmt->execute([$product_id]);
    $product = $stmt->fetch();

    if (!$product) {
        header("Location: finished_goods_inventory.php");
        exit;
    }
} catch (PDOException $e) {
    $error_message = "获取产品信息失败：" . $e->getMessage();
}

// 获取销售订单列表（用于销售出库选择）
try {
    $stmt = $pdo->prepare("
        SELECT 
            so.id,
            so.order_number,
            so.customer_id,
            c.name AS customer_name,
            so.order_date,
            so.status
        FROM 
            sales_orders so
        JOIN 
            customers c ON so.customer_id = c.id
        JOIN 
            sales_order_items soi ON so.id = soi.sales_order_id
        WHERE 
            soi.product_id = ?
            AND so.status IN ('confirmed', 'processing', 'partially_shipped')
            AND soi.quantity > soi.shipped_quantity
        ORDER BY 
            so.order_date DESC
    ");
    $stmt->execute([$product_id]);
    $sales_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error_message = "获取销售订单列表失败：" . $e->getMessage();
}

// 处理出库表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $pdo->beginTransaction();

    try {
        $outbound_type = trim($_POST['outbound_type'] ?? '');
        $quantity = (float)($_POST['quantity'] ?? 0);
        $notes = trim($_POST['notes'] ?? '');
        $sales_order_id = (int)($_POST['sales_order_id'] ?? 0);
        $inventory_id = (int)($_POST['inventory_id'] ?? 0);

        // 验证数据
        if ($quantity <= 0) {
            throw new Exception("出库数量必须大于0");
        }

        if ($quantity > $product['quantity_on_hand']) {
            throw new Exception("出库数量不能超过当前库存量（{$product['quantity_on_hand']} {$product['unit']}）");
        }

        if (!in_array($outbound_type, ['sales', 'waste', 'other'])) {
            throw new Exception("请选择有效的出库类型");
        }

        if ($outbound_type === 'sales' && $sales_order_id <= 0) {
            throw new Exception("销售出库必须选择销售订单");
        }

        // 1. 更新库存数量
        $stmt = $pdo->prepare("
            UPDATE inventory 
            SET quantity_on_hand = quantity_on_hand - ?, last_updated = CURRENT_TIMESTAMP 
            WHERE id = ?
        ");
        $stmt->execute([$quantity, $inventory_id]);

        // 2. 记录活动日志
        $action = "产品出库";
        switch ($outbound_type) {
            case 'sales':
                $action = "销售出库";
                break;
            case 'waste':
                $action = "损耗出库";
                break;
            case 'other':
                $action = "其他出库";
                break;
        }

        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, 'product', ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            $action,
            $product_id,
            "出库数量: {$quantity} {$product['unit']}, 备注: {$notes}",
            $_SERVER['REMOTE_ADDR']
        ]);
        $log_id = $pdo->lastInsertId();

        // 3. 如果是销售出库，处理销售订单相关逻辑
        if ($outbound_type === 'sales') {
            // 获取订单项信息
            $stmt = $pdo->prepare("
                SELECT 
                    id, 
                    quantity, 
                    shipped_quantity 
                FROM 
                    sales_order_items 
                WHERE 
                    sales_order_id = ? 
                    AND product_id = ?
            ");
            $stmt->execute([$sales_order_id, $product_id]);
            $orderItem = $stmt->fetch();

            if (!$orderItem) {
                throw new Exception("未找到相关销售订单项");
            }

            // 计算可发货数量
            $remainingQuantity = $orderItem['quantity'] - $orderItem['shipped_quantity'];
            if ($quantity > $remainingQuantity) {
                throw new Exception("出库数量不能超过订单剩余未发货数量 ({$remainingQuantity} {$product['unit']})");
            }

            // 更新订单项的已发货数量
            $stmt = $pdo->prepare("
                UPDATE sales_order_items 
                SET shipped_quantity = shipped_quantity + ? 
                WHERE id = ?
            ");
            $stmt->execute([$quantity, $orderItem['id']]);

            // 获取销售订单信息
            $stmt = $pdo->prepare("
                SELECT status FROM sales_orders WHERE id = ?
            ");
            $stmt->execute([$sales_order_id]);
            $order = $stmt->fetch();

            // 检查订单所有项目是否已全部发货
            $stmt = $pdo->prepare("
                SELECT 
                    SUM(quantity) AS total_quantity,
                    SUM(shipped_quantity) AS total_shipped
                FROM 
                    sales_order_items 
                WHERE 
                    sales_order_id = ?
            ");
            $stmt->execute([$sales_order_id]);
            $totals = $stmt->fetch();

            // 更新订单状态
            $newStatus = $order['status'];
            if ($totals['total_shipped'] >= $totals['total_quantity']) {
                $newStatus = 'shipped';
            } else if ($totals['total_shipped'] > 0) {
                $newStatus = 'partially_shipped';
            }

            if ($newStatus !== $order['status']) {
                $stmt = $pdo->prepare("
                    UPDATE sales_orders 
                    SET status = ? 
                    WHERE id = ?
                ");
                $stmt->execute([$newStatus, $sales_order_id]);
            }

            // 生成发货记录
            $shipmentNumber = 'SHP' . date('YmdHis');
            $stmt = $pdo->prepare("
                INSERT INTO shipments 
                (shipment_number, sales_order_id, shipment_date, status, notes, created_at) 
                VALUES (?, ?, NOW(), 'ready_to_ship', ?, CURRENT_TIMESTAMP)
            ");
            $stmt->execute([$shipmentNumber, $sales_order_id, $notes]);
            $shipment_id = $pdo->lastInsertId();
        }

        $pdo->commit();
        $success_message = "成功出库 {$quantity} {$product['unit']} {$product['product_name']}";

        // 刷新产品信息
        $stmt = $pdo->prepare("
            SELECT quantity_on_hand FROM inventory WHERE id = ?
        ");
        $stmt->execute([$inventory_id]);
        $updated = $stmt->fetch();
        $product['quantity_on_hand'] = $updated['quantity_on_hand'];

        // 出库成功后跳转到详情页
        if (isset($shipment_id) && $shipment_id > 0) {
            header("Location: outbound_detail.php?shipment_id={$shipment_id}");
            exit;
        } else {
            header("Location: outbound_detail.php?id={$log_id}");
            exit;
        }
    } catch (Exception $e) {
        $pdo->rollBack();
        $error_message = $e->getMessage();
    }
}

// 定义出库类型
$outbound_types = [
    'sales' => '销售出库',
    'waste' => '损耗出库',
    'other' => '其他出库'
];

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>创建出库 - <?= htmlspecialchars($product['product_name']) ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .container {
            max-width: 800px;
            margin: 50px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .product-info {
            background-color: #f8f9fa;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }

        .product-name {
            font-size: 1.2em;
            font-weight: bold;
            margin-bottom: 5px;
        }

        .product-details {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 10px;
        }

        .alert {
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        .form-row {
            margin-bottom: 15px;
        }

        .form-row label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }

        .form-row input,
        .form-row select,
        .form-row textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ced4da;
            border-radius: 4px;
        }

        .form-row textarea {
            height: 100px;
            resize: vertical;
        }

        .btn-container {
            display: flex;
            justify-content: space-between;
            margin-top: 20px;
        }

        .btn {
            padding: 10px 20px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 16px;
        }

        .btn-primary {
            background-color: #3498db;
            color: white;
        }

        .btn-secondary {
            background-color: #6c757d;
            color: white;
        }

        .btn-primary:hover {
            background-color: #2980b9;
        }

        .btn-secondary:hover {
            background-color: #5a6268;
        }

        .hidden {
            display: none;
        }

        .current-stock {
            color: #2ecc71;
            font-weight: bold;
        }

        .low-stock {
            color: #e74c3c;
            font-weight: bold;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>创建出库单</h2>

        <?php if ($success_message): ?>
            <div class="alert alert-success"><?= $success_message ?></div>
        <?php endif; ?>

        <?php if ($error_message): ?>
            <div class="alert alert-danger"><?= $error_message ?></div>
        <?php endif; ?>

        <div class="product-info">
            <div class="product-name"><?= htmlspecialchars($product['product_name']) ?></div>
            <div class="product-details">
                <div>规格: <?= htmlspecialchars($product['specification'] ?? '无') ?></div>
                <div>库存位置: <?= htmlspecialchars($product['location_name']) ?></div>
                <div>当前库存:
                    <span class="<?= $product['quantity_on_hand'] > 0 ? 'current-stock' : 'low-stock' ?>">
                        <?= number_format($product['quantity_on_hand'], 2) ?> <?= htmlspecialchars($product['unit']) ?>
                    </span>
                </div>
            </div>
        </div>

        <form method="post" action="">
            <input type="hidden" name="inventory_id" value="<?= $product['inventory_id'] ?>">

            <div class="form-row">
                <label for="outbound_type">出库类型</label>
                <select name="outbound_type" id="outbound_type" required onchange="toggleSalesOrderField()">
                    <option value="">请选择出库类型</option>
                    <?php foreach ($outbound_types as $value => $label): ?>
                        <option value="<?= $value ?>"><?= $label ?></option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-row">
                <label for="quantity">出库数量 (<?= htmlspecialchars($product['unit']) ?>)</label>
                <input type="number" name="quantity" id="quantity" required step="0.01" min="0.01" max="<?= $product['quantity_on_hand'] ?>">
                <small>最大可出库数量: <?= number_format($product['quantity_on_hand'], 2) ?> <?= htmlspecialchars($product['unit']) ?></small>
            </div>

            <div class="form-row" id="sales_order_field" style="display:none;">
                <label for="sales_order_id">关联销售订单</label>
                <select name="sales_order_id" id="sales_order_id">
                    <option value="">请选择销售订单</option>
                    <?php foreach ($sales_orders as $order): ?>
                        <option value="<?= $order['id'] ?>">
                            <?= htmlspecialchars($order['order_number']) ?> -
                            <?= htmlspecialchars($order['customer_name']) ?>
                            (<?= date('Y-m-d', strtotime($order['order_date'])) ?>)
                        </option>
                    <?php endforeach; ?>
                </select>
                <?php if (empty($sales_orders)): ?>
                    <small>暂无未完成的销售订单，系统将创建新的发货记录</small>
                <?php endif; ?>
            </div>

            <div class="form-row">
                <label for="notes">备注说明</label>
                <textarea name="notes" id="notes" placeholder="请输入出库说明或备注信息"></textarea>
            </div>

            <div class="btn-container">
                <button type="button" class="btn btn-secondary" onclick="window.location.href='finished_goods_inventory.php'">返回库存列表</button>
                <button type="submit" class="btn btn-primary">确认出库</button>
            </div>
        </form>
    </div>

    <script>
        function toggleSalesOrderField() {
            const outboundType = document.getElementById('outbound_type').value;
            const salesOrderField = document.getElementById('sales_order_field');
            const salesOrderSelect = document.getElementById('sales_order_id');

            if (outboundType === 'sales') {
                salesOrderField.style.display = 'block';
                <?php if (!empty($sales_orders)): ?>
                    salesOrderSelect.required = true;
                <?php endif; ?>
            } else {
                salesOrderField.style.display = 'none';
                salesOrderSelect.required = false;
            }
        }

        // 初始化页面
        document.addEventListener('DOMContentLoaded', function() {
            toggleSalesOrderField();
        });
    </script>
</body>

</html>