<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取产品ID
$product_id = isset($_GET['product_id']) ? (int)$_GET['product_id'] : 0;

if ($product_id <= 0) {
    header("Location: raw_material_inventory.php");
    exit;
}

// 获取日期范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-1 month'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

try {
    // 获取产品基本信息
    $stmt = $pdo->prepare("
        SELECT 
            p.id,
            p.name,
            p.description,
            p.specification,
            p.unit,
            SUM(i.quantity_on_hand) AS total_quantity
        FROM 
            products p
        LEFT JOIN 
            inventory i ON p.id = i.product_id
        WHERE 
            p.id = ? AND p.type = 'raw'
        GROUP BY 
            p.id
    ");
    $stmt->execute([$product_id]);
    $product = $stmt->fetch();

    if (!$product) {
        header("Location: raw_material_inventory.php");
        exit;
    }

    // 获取产品库存分布
    $stmt = $pdo->prepare("
        SELECT 
            i.storage_location_id,
            sl.name AS location_name,
            i.quantity_on_hand,
            i.unit,
            i.low_stock_threshold,
            i.last_updated
        FROM 
            inventory i
        JOIN 
            storage_locations sl ON i.storage_location_id = sl.id
        WHERE 
            i.product_id = ?
        ORDER BY 
            sl.name
    ");
    $stmt->execute([$product_id]);
    $inventoryLocations = $stmt->fetchAll();

    // 获取入库记录
    $stmt = $pdo->prepare("
        SELECT 
            'material_receiving' AS record_type,
            mr.id,
            mr.received_date AS action_date,
            '入库' AS action_type,
            mr.received_quantity AS quantity_change,
            mr.batch_number,
            mr.quality_check_result,
            po.order_number,
            u.username AS operator,
            sl.name AS location_name
        FROM 
            material_receiving mr
        LEFT JOIN 
            purchase_order_items poi ON mr.purchase_order_item_id = poi.id
        LEFT JOIN 
            purchase_orders po ON poi.purchase_order_id = po.id
        LEFT JOIN 
            users u ON mr.inspector_id = u.id
        LEFT JOIN 
            storage_locations sl ON mr.storage_location_id = sl.id
        WHERE 
            mr.product_id = ?
            AND mr.received_date BETWEEN ? AND ?
        ORDER BY 
            mr.received_date DESC
    ");
    $stmt->execute([$product_id, $start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $receivingRecords = $stmt->fetchAll();

    // 简单获取活动日志中与此原料相关的记录
    $stmt = $pdo->prepare("
        SELECT 
            'activity_log' AS record_type,
            id,
            timestamp AS action_date,
            action AS action_type,
            NULL AS quantity_change,
            NULL AS batch_number,
            NULL AS quality_check_result,
            NULL AS order_number,
            username AS operator,
            NULL AS location_name
        FROM 
            activity_log
        WHERE 
            target_type = 'product' 
            AND target_id = ?
            AND timestamp BETWEEN ? AND ?
        ORDER BY 
            timestamp DESC
    ");
    $stmt->execute([$product_id, $start_date . ' 00:00:00', $end_date . ' 23:59:59']);
    $logRecords = $stmt->fetchAll();

    // 合并两种记录并按日期降序排序
    $allRecords = array_merge($receivingRecords, $logRecords);
    usort($allRecords, function ($a, $b) {
        return strtotime($b['action_date']) - strtotime($a['action_date']);
    });

    // 质检结果对应的显示文本和样式
    $qualityResultDisplay = [
        'passed' => ['text' => '合格', 'class' => '已完成'],
        'failed' => ['text' => '不合格', 'class' => '待处理'],
        'pending' => ['text' => '待检验', 'class' => '进行中']
    ];
} catch (PDOException $e) {
    $error = "查询数据失败：" . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= htmlspecialchars($product['name']) ?> - 库存记录</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .product-overview {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 20px;
            margin-bottom: 30px;
        }

        .product-info,
        .inventory-locations {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 20px;
        }

        .product-title {
            margin-top: 0;
            color: #2c3e50;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }

        .product-detail {
            margin-bottom: 10px;
        }

        .detail-label {
            font-weight: bold;
            color: #555;
        }

        .location-card {
            background: #f8f9fa;
            border-radius: 6px;
            padding: 10px;
            margin-bottom: 10px;
            border-left: 4px solid #3498db;
        }

        .location-name {
            font-weight: bold;
            margin-bottom: 5px;
            color: #2c3e50;
        }

        .quantity-info {
            display: flex;
            justify-content: space-between;
        }

        .filter-form {
            background: #f8f9fa;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
            display: flex;
            gap: 15px;
            align-items: center;
        }

        .filter-form label {
            font-weight: bold;
            margin-right: 5px;
        }

        .filter-form input[type="date"] {
            padding: 8px;
            border: 1px solid #ced4da;
            border-radius: 4px;
        }

        .filter-form button {
            padding: 8px 16px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .filter-form button:hover {
            background-color: #2980b9;
        }

        .records-table {
            width: 100%;
            border-collapse: collapse;
        }

        .records-table th,
        .records-table td {
            padding: 12px;
            text-align: left;
            border-bottom: 1px solid #ddd;
        }

        .records-table th {
            background-color: #f8f9fa;
            color: #2c3e50;
            font-weight: bold;
        }

        .records-table tr:hover {
            background-color: #f1f1f1;
        }

        .records-table .quantity-increase {
            color: #28a745;
            font-weight: bold;
        }

        .records-table .quantity-decrease {
            color: #dc3545;
            font-weight: bold;
        }

        .low-stock {
            color: #e74c3c;
            font-weight: bold;
        }

        .back-button {
            margin-bottom: 20px;
            display: inline-block;
            padding: 8px 16px;
            background-color: #6c757d;
            color: white;
            text-decoration: none;
            border-radius: 4px;
        }

        .back-button:hover {
            background-color: #5a6268;
        }
    </style>
</head>

<body>
    <div class="container">
        <a href="raw_material_inventory.php" class="back-button">返回库存列表</a>

        <h2><?= htmlspecialchars($product['name']) ?> 库存记录</h2>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <div class="product-overview">
            <div class="product-info">
                <h3 class="product-title">基本信息</h3>
                <div class="product-detail">
                    <span class="detail-label">名称：</span>
                    <?= htmlspecialchars($product['name']) ?>
                </div>
                <?php if (!empty($product['specification'])): ?>
                    <div class="product-detail">
                        <span class="detail-label">规格：</span>
                        <?= htmlspecialchars($product['specification']) ?>
                    </div>
                <?php endif; ?>
                <div class="product-detail">
                    <span class="detail-label">单位：</span>
                    <?= htmlspecialchars($product['unit']) ?>
                </div>
                <div class="product-detail">
                    <span class="detail-label">总库存：</span>
                    <?= number_format($product['total_quantity'], 2) ?> <?= htmlspecialchars($product['unit']) ?>
                </div>
                <?php if (!empty($product['description'])): ?>
                    <div class="product-detail">
                        <span class="detail-label">描述：</span>
                        <?= htmlspecialchars($product['description']) ?>
                    </div>
                <?php endif; ?>
            </div>

            <div class="inventory-locations">
                <h3 class="product-title">库存分布</h3>
                <?php if (empty($inventoryLocations)): ?>
                    <p>暂无库存记录</p>
                <?php else: ?>
                    <?php foreach ($inventoryLocations as $location): ?>
                        <div class="location-card">
                            <div class="location-name"><?= htmlspecialchars($location['location_name']) ?></div>
                            <div class="quantity-info">
                                <div>
                                    <span class="detail-label">数量：</span>
                                    <?= number_format($location['quantity_on_hand'], 2) ?> <?= htmlspecialchars($location['unit']) ?>
                                </div>
                                <?php if ($location['low_stock_threshold'] > 0 && $location['quantity_on_hand'] <= $location['low_stock_threshold']): ?>
                                    <div class="low-stock">
                                        低于预警值 (<?= $location['low_stock_threshold'] ?>)
                                    </div>
                                <?php endif; ?>
                            </div>
                            <small>最后更新: <?= date('Y-m-d H:i', strtotime($location['last_updated'])) ?></small>
                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>
        </div>

        <h3>历史记录</h3>

        <form method="GET" action="inventory_history.php" class="filter-form">
            <input type="hidden" name="product_id" value="<?= $product_id ?>">
            <div>
                <label for="start_date">开始日期：</label>
                <input type="date" id="start_date" name="start_date" value="<?= $start_date ?>">
            </div>
            <div>
                <label for="end_date">结束日期：</label>
                <input type="date" id="end_date" name="end_date" value="<?= $end_date ?>">
            </div>
            <button type="submit">筛选</button>
            <button type="button" onclick="resetFilters()">重置</button>
        </form>

        <?php if (empty($allRecords)): ?>
            <div class="empty-state">
                <p>所选时间范围内暂无记录</p>
            </div>
        <?php else: ?>
            <table class="records-table">
                <thead>
                    <tr>
                        <th>时间</th>
                        <th>操作类型</th>
                        <th>数量变化</th>
                        <th>批次号</th>
                        <th>质检结果</th>
                        <th>关联单号</th>
                        <th>操作人员</th>
                        <th>存放位置</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($allRecords as $record): ?>
                        <?php
                        $quantityClass = '';
                        if (!is_null($record['quantity_change'])) {
                            $quantityClass = $record['quantity_change'] > 0 ? 'quantity-increase' : 'quantity-decrease';
                        }

                        $qualityInfo = [];
                        if (!is_null($record['quality_check_result']) && isset($qualityResultDisplay[$record['quality_check_result']])) {
                            $qualityInfo = $qualityResultDisplay[$record['quality_check_result']];
                        }
                        ?>
                        <tr>
                            <td><?= date('Y-m-d H:i', strtotime($record['action_date'])) ?></td>
                            <td><?= htmlspecialchars($record['action_type']) ?></td>
                            <td class="<?= $quantityClass ?>">
                                <?= !is_null($record['quantity_change']) ? (($record['quantity_change'] > 0 ? '+' : '') . number_format($record['quantity_change'], 2) . ' ' . $product['unit']) : '-' ?>
                            </td>
                            <td><?= htmlspecialchars($record['batch_number'] ?? '-') ?></td>
                            <td>
                                <?php if (!empty($qualityInfo)): ?>
                                    <span class="status-tag <?= $qualityInfo['class'] ?>"><?= $qualityInfo['text'] ?></span>
                                <?php else: ?>
                                    -
                                <?php endif; ?>
                            </td>
                            <td><?= htmlspecialchars($record['order_number'] ?? '-') ?></td>
                            <td><?= htmlspecialchars($record['operator'] ?? '-') ?></td>
                            <td><?= htmlspecialchars($record['location_name'] ?? '-') ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php endif; ?>
    </div>

    <script>
        function resetFilters() {
            window.location.href = 'inventory_history.php?product_id=<?= $product_id ?>';
        }
    </script>
</body>

</html>