<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 状态映射
$status_map = [
    'pending' => '待处理',
    'ready_to_ship' => '待发货',
    'shipped' => '已发货',
    'in_transit' => '运输中',
    'delivered' => '已送达',
    'failed' => '发货失败',
    'cancelled' => '已取消'
];

// 获取过滤条件
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$status_filter = isset($_GET['status']) ? $_GET['status'] : '';
$carrier_filter = isset($_GET['carrier_id']) ? (int)$_GET['carrier_id'] : 0;
$date_from = isset($_GET['date_from']) ? $_GET['date_from'] : '';
$date_to = isset($_GET['date_to']) ? $_GET['date_to'] : '';

// 初始化变量
$shipments = [];
$carriers = [];
$error = '';

// 获取所有物流公司
try {
    $stmt = $pdo->query("
        SELECT id, name, service_type 
        FROM carriers 
        WHERE is_active = 1 
        ORDER BY name
    ");
    $carriers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取物流公司失败: " . $e->getMessage();
}

// 获取物流追踪列表
try {
    $params = [];
    $sql = "
        SELECT 
            s.id,
            s.shipment_number,
            s.tracking_number,
            s.shipment_date,
            s.estimated_delivery_date,
            s.actual_delivery_date,
            s.status,
            so.order_number,
            c.name AS customer_name,
            cr.name AS carrier_name
        FROM 
            shipments s
        JOIN 
            sales_orders so ON s.sales_order_id = so.id
        LEFT JOIN 
            customers c ON so.customer_id = c.id
        LEFT JOIN 
            carriers cr ON s.carrier_id = cr.id
        WHERE 1=1
    ";

    // 添加搜索条件
    if (!empty($search)) {
        $sql .= " AND (s.shipment_number LIKE ? OR s.tracking_number LIKE ? OR so.order_number LIKE ?)";
        $search_param = "%$search%";
        $params[] = $search_param;
        $params[] = $search_param;
        $params[] = $search_param;
    }

    // 状态过滤
    if (!empty($status_filter)) {
        $sql .= " AND s.status = ?";
        $params[] = $status_filter;
    }

    // 物流公司过滤
    if ($carrier_filter > 0) {
        $sql .= " AND s.carrier_id = ?";
        $params[] = $carrier_filter;
    }

    // 日期范围过滤
    if (!empty($date_from)) {
        $sql .= " AND s.shipment_date >= ?";
        $params[] = $date_from . ' 00:00:00';
    }
    if (!empty($date_to)) {
        $sql .= " AND s.shipment_date <= ?";
        $params[] = $date_to . ' 23:59:59';
    }

    // 排序
    $sql .= " ORDER BY s.shipment_date DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $shipments = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取物流追踪信息失败: " . $e->getMessage();
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>物流追踪列表 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 页面特定样式 */
        body {
            background-color: #f8f9fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .filter-container {
            margin-bottom: 20px;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

        .search-bar {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            align-items: flex-end;
        }

        .search-bar input,
        .search-bar select {
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            flex: 1;
            min-width: 150px;
        }

        .search-bar button {
            padding: 10px 15px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .search-bar button.btn-cancel {
            background-color: #6c757d;
        }

        .search-bar button:hover {
            opacity: 0.9;
        }

        .table-container {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
            overflow: hidden;
        }

        table {
            width: 100%;
            border-collapse: collapse;
        }

        table th,
        table td {
            padding: 12px 15px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }

        table th {
            background-color: #f8f9fa;
            color: #333;
            font-weight: bold;
            white-space: nowrap;
        }

        table tr:hover {
            background-color: #f6f9fc;
        }

        .status-tag {
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 12px;
            font-weight: bold;
            color: white;
            white-space: nowrap;
        }

        .pending,
        .ready_to_ship {
            background-color: #f39c12;
        }

        .shipped,
        .in_transit {
            background-color: #3498db;
        }

        .delivered {
            background-color: #2ecc71;
        }

        .failed,
        .cancelled {
            background-color: #e74c3c;
        }

        .btn-track {
            display: block;
            padding: 6px 12px;
            background-color: #3498db;
            color: white;
            text-decoration: none;
            border-radius: 4px;
            font-size: 13px;
            margin-bottom: 5px;
        }

        .btn-track:hover {
            background-color: #2980b9;
            color: white;
        }

        .btn-container {
            display: flex;
            flex-direction: column;
        }

        .text-muted {
            color: #6c757d;
        }

        .empty-state {
            text-align: center;
            padding: 40px;
            color: #6c757d;
            background-color: #f8f9fa;
            border-radius: 8px;
            margin: 20px 0;
        }

        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }
    </style>
</head>

<body>
    <div class="content">
        <h1>物流追踪列表</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <div class="filter-container">
            <form action="" method="GET" class="search-bar">
                <input type="text" name="search" placeholder="搜索发货单号/物流单号/订单号" value="<?= htmlspecialchars($search) ?>">

                <select name="status">
                    <option value="">所有状态</option>
                    <?php foreach ($status_map as $key => $value): ?>
                        <option value="<?= $key ?>" <?= $status_filter === $key ? 'selected' : '' ?>><?= $value ?></option>
                    <?php endforeach; ?>
                </select>

                <select name="carrier_id">
                    <option value="0">所有物流公司</option>
                    <?php foreach ($carriers as $carrier): ?>
                        <option value="<?= $carrier['id'] ?>" <?= $carrier_filter === $carrier['id'] ? 'selected' : '' ?>><?= htmlspecialchars($carrier['name']) ?></option>
                    <?php endforeach; ?>
                </select>

                <input type="date" name="date_from" placeholder="起始日期" value="<?= htmlspecialchars($date_from) ?>">
                <input type="date" name="date_to" placeholder="结束日期" value="<?= htmlspecialchars($date_to) ?>">

                <button type="submit">筛选</button>
                <button type="button" onclick="location.href='tracking_list.php'" class="btn-cancel">重置</button>
            </form>
        </div>

        <div class="table-container">
            <?php if (empty($shipments)): ?>
                <div class="empty-state">
                    <p>暂无物流追踪信息</p>
                </div>
            <?php else: ?>
                <table>
                    <thead>
                        <tr>
                            <th>发货单号</th>
                            <th>订单号</th>
                            <th>物流单号</th>
                            <th>物流公司</th>
                            <th>客户</th>
                            <th>发货日期</th>
                            <th>预计送达</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($shipments as $shipment): ?>
                            <tr>
                                <td><?= htmlspecialchars($shipment['shipment_number']) ?></td>
                                <td><?= htmlspecialchars($shipment['order_number']) ?></td>
                                <td><?= htmlspecialchars($shipment['tracking_number']) ?></td>
                                <td><?= htmlspecialchars($shipment['carrier_name'] ?: '-') ?></td>
                                <td><?= htmlspecialchars($shipment['customer_name']) ?></td>
                                <td><?= date('Y-m-d', strtotime($shipment['shipment_date'])) ?></td>
                                <td><?= $shipment['estimated_delivery_date'] ? date('Y-m-d', strtotime($shipment['estimated_delivery_date'])) : '-' ?></td>
                                <td>
                                    <span class="status-tag <?= $shipment['status'] ?>">
                                        <?= $status_map[$shipment['status']] ?? $shipment['status'] ?>
                                    </span>
                                </td>
                                <td class="text-center">
                                    <?php if (!empty($shipment['tracking_number'])): ?>
                                        <div class="btn-container">
                                            <a href="shipment_tracking.php?tracking_number=<?= urlencode($shipment['tracking_number']) ?>&carrier=<?= urlencode($shipment['carrier_name']) ?>&id=<?= $shipment['id'] ?>&from_list=1" class="btn-track">追踪详情</a>
                                        </div>
                                    <?php else: ?>
                                        <span class="text-muted">暂无追踪号</span>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>