<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取计划ID（如果有）
$plan_id = isset($_GET['plan_id']) ? (int)$_GET['plan_id'] : null;

// 获取批次ID和操作（如果有）
$batch_id = isset($_GET['batch_id']) ? (int)$_GET['batch_id'] : null;
$action = isset($_GET['action']) ? $_GET['action'] : null;

// 获取计划信息（如果指定了计划ID）
$plan = null;
if ($plan_id) {
    $stmt = $pdo->prepare("
        SELECT pp.*, p.name AS product_name, p.type AS product_type, p.unit
        FROM production_plans pp
        JOIN products p ON pp.product_id = p.id
        WHERE pp.id = ?
    ");
    $stmt->execute([$plan_id]);
    $plan = $stmt->fetch();

    if (!$plan) {
        $_SESSION['error'] = "找不到指定的生产计划";
        header("Location: production_plans.php");
        exit;
    }
}

// 获取产品列表（用于创建新批次）
$products = $pdo->query("
    SELECT id, name, type, unit, specification
    FROM products
    WHERE type IN ('semi-finished', 'finished')
    ORDER BY type, name
")->fetchAll();

// 生成新批次编号
$today = date('Ymd');
$stmt = $pdo->prepare("
    SELECT COUNT(*) 
    FROM production_batches 
    WHERE batch_number LIKE ?
");
$stmt->execute(["B$today%"]);
$count = $stmt->fetchColumn() + 1;
$newBatchNumber = "B$today" . str_pad($count, 3, '0', STR_PAD_LEFT);

// 处理批次状态更新
if ($_SERVER['REQUEST_METHOD'] === 'GET' && $action && $batch_id) {
    try {
        $pdo->beginTransaction();

        // 获取当前批次信息
        $stmt = $pdo->prepare("SELECT batch_number, status FROM production_batches WHERE id = ?");
        $stmt->execute([$batch_id]);
        $batch = $stmt->fetch();

        if (!$batch) {
            throw new Exception("生产批次不存在");
        }

        $new_status = null;
        $updateFields = [];
        $updateParams = [];

        // 根据不同操作设置新状态和更新字段
        switch ($action) {
            case 'start':
                if ($batch['status'] !== 'planned') {
                    throw new Exception("只有计划状态的批次可以开始生产");
                }
                $new_status = 'in_progress';
                $updateFields[] = "status = ?";
                $updateFields[] = "start_time = CURRENT_TIMESTAMP";
                $updateParams[] = $new_status;
                break;

            case 'complete':
                if ($batch['status'] !== 'in_progress') {
                    throw new Exception("只有进行中的批次可以完成生产");
                }
                $new_status = 'completed';
                $updateFields[] = "status = ?";
                $updateFields[] = "end_time = CURRENT_TIMESTAMP";
                $updateParams[] = $new_status;
                break;

            case 'quality_check':
                if ($batch['status'] !== 'completed') {
                    throw new Exception("只有完成生产的批次可以送检");
                }
                $new_status = 'quality_check';
                $updateFields[] = "status = ?";
                $updateParams[] = $new_status;
                break;

            case 'stock':
                if ($batch['status'] !== 'quality_check') {
                    throw new Exception("只有质检完成的批次可以入库");
                }
                $new_status = 'stocked';
                $updateFields[] = "status = ?";
                $updateParams[] = $new_status;
                break;

            case 'cancel':
                if (!in_array($batch['status'], ['planned', 'in_progress'])) {
                    throw new Exception("只有计划或进行中的批次可以取消");
                }
                $new_status = 'cancelled';
                $updateFields[] = "status = ?";
                $updateParams[] = $new_status;
                break;

            default:
                throw new Exception("无效的操作");
        }

        if ($new_status) {
            // 更新批次状态
            $stmt = $pdo->prepare("
                UPDATE production_batches 
                SET " . implode(", ", $updateFields) . "
                WHERE id = ?
            ");
            $updateParams[] = $batch_id;
            $stmt->execute($updateParams);

            // 记录日志
            $stmt = $pdo->prepare("
                INSERT INTO activity_log 
                (user_id, username, action, target_type, target_id, details, ip_address) 
                VALUES (?, ?, ?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $_SESSION['user_id'],
                $_SESSION['username'],
                '更新批次状态',
                'production_batch',
                $batch_id,
                json_encode([
                    'batch_number' => $batch['batch_number'],
                    'old_status' => $batch['status'],
                    'new_status' => $new_status
                ]),
                $_SERVER['REMOTE_ADDR']
            ]);

            $pdo->commit();
            $_SESSION['success'] = "批次 {$batch['batch_number']} 状态已更新为 " . getStatusName($new_status);
        }
    } catch (Exception $e) {
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        $_SESSION['error'] = $e->getMessage();
    }

    header("Location: batch_management.php" . ($plan_id ? "?plan_id=$plan_id" : ""));
    exit;
}

// 处理创建新批次
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'create_batch') {
    // 验证CSRF Token
    if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
        $_SESSION['error'] = "安全验证失败，请重试";
        header("Location: batch_management.php" . ($plan_id ? "?plan_id=$plan_id" : ""));
        exit;
    }

    try {
        // 获取表单数据
        $batch_number = $_POST['batch_number'] ?? $newBatchNumber;
        $production_plan_id = !empty($_POST['production_plan_id']) ? (int)$_POST['production_plan_id'] : null;
        $product_id = (int)($_POST['product_id'] ?? 0);
        $quantity_planned = (float)($_POST['quantity_planned'] ?? 0);
        $start_time = !empty($_POST['start_time']) ? $_POST['start_time'] : null;
        $end_time = !empty($_POST['end_time']) ? $_POST['end_time'] : null;
        $status = $_POST['status'] ?? 'planned';
        $estimated_cost = !empty($_POST['estimated_cost']) ? (float)$_POST['estimated_cost'] : null;
        $notes = trim($_POST['notes'] ?? '');

        // 验证数据
        if (empty($batch_number) || $product_id <= 0 || $quantity_planned <= 0) {
            throw new Exception("批次号、产品和计划产量为必填项");
        }

        // 检查批次号是否已存在
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM production_batches WHERE batch_number = ?");
        $stmt->execute([$batch_number]);
        if ($stmt->fetchColumn() > 0) {
            throw new Exception("批次号 '$batch_number' 已存在");
        }

        // 开始事务
        $pdo->beginTransaction();

        // 创建批次
        $stmt = $pdo->prepare("
            INSERT INTO production_batches 
            (batch_number, production_plan_id, product_id, quantity_planned, start_time, end_time, 
             status, estimated_cost, notes) 
            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $batch_number,
            $production_plan_id,
            $product_id,
            $quantity_planned,
            $start_time,
            $end_time,
            $status,
            $estimated_cost,
            $notes ?: null
        ]);

        $batch_id = $pdo->lastInsertId();

        // 记录日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '创建生产批次',
            'production_batch',
            $batch_id,
            json_encode([
                'batch_number' => $batch_number,
                'product_id' => $product_id,
                'production_plan_id' => $production_plan_id,
                'quantity_planned' => $quantity_planned
            ]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "生产批次 $batch_number 创建成功";

        // 重定向，避免刷新重复提交
        header("Location: batch_management.php" . ($plan_id ? "?plan_id=$plan_id" : ""));
        exit;
    } catch (Exception $e) {
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        $_SESSION['error'] = "创建批次失败: " . $e->getMessage();
    }
}

// 处理更新产量信息
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'update_production') {
    // 验证CSRF Token
    if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
        $_SESSION['error'] = "安全验证失败，请重试";
        header("Location: batch_management.php" . ($plan_id ? "?plan_id=$plan_id" : ""));
        exit;
    }

    try {
        $batch_id = (int)($_POST['batch_id'] ?? 0);
        $quantity_produced = (float)($_POST['quantity_produced'] ?? 0);
        $actual_cost = !empty($_POST['actual_cost']) ? (float)$_POST['actual_cost'] : null;

        if ($batch_id <= 0 || $quantity_produced <= 0) {
            throw new Exception("批次ID和实际产量为必填项");
        }

        $pdo->beginTransaction();

        // 更新产量
        $stmt = $pdo->prepare("
            UPDATE production_batches 
            SET quantity_produced = ?, actual_cost = ?, updated_at = CURRENT_TIMESTAMP
            WHERE id = ?
        ");
        $stmt->execute([$quantity_produced, $actual_cost, $batch_id]);

        // 获取批次信息以记录日志
        $stmt = $pdo->prepare("SELECT batch_number FROM production_batches WHERE id = ?");
        $stmt->execute([$batch_id]);
        $batch = $stmt->fetch();

        // 记录日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '更新批次产量',
            'production_batch',
            $batch_id,
            json_encode([
                'batch_number' => $batch['batch_number'],
                'quantity_produced' => $quantity_produced,
                'actual_cost' => $actual_cost
            ]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "批次 {$batch['batch_number']} 产量信息已更新";
    } catch (Exception $e) {
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        $_SESSION['error'] = "更新产量失败: " . $e->getMessage();
    }

    header("Location: batch_management.php" . ($plan_id ? "?plan_id=$plan_id" : ""));
    exit;
}

// 获取批次列表
$batchesQuery = "
    SELECT 
        pb.id,
        pb.production_plan_id as plan_id, 
        pb.batch_number, 
        pp.plan_number, 
        p.name AS product_name, 
        p.type AS product_type,
        p.unit,
        pb.quantity_planned, 
        pb.quantity_produced, 
        pb.start_time, 
        pb.end_time, 
        pb.status,
        pb.estimated_cost,
        pb.actual_cost,
        pb.notes
    FROM production_batches pb
    LEFT JOIN production_plans pp ON pb.production_plan_id = pp.id
    JOIN products p ON pb.product_id = p.id
";

$batchesParams = [];
if ($plan_id) {
    $batchesQuery .= " WHERE pb.production_plan_id = ?";
    $batchesParams[] = $plan_id;
}

$batchesQuery .= " ORDER BY pb.created_at DESC";

$stmt = $pdo->prepare($batchesQuery);
$stmt->execute($batchesParams);
$batches = $stmt->fetchAll();

// 状态名称转换函数
function getStatusName($status)
{
    $statusMap = [
        'planned' => '已计划',
        'in_progress' => '生产中',
        'completed' => '已完成',
        'quality_check' => '质检中',
        'stocked' => '已入库',
        'cancelled' => '已取消'
    ];
    return $statusMap[$status] ?? $status;
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>批次管理 - FruitEase</title>
    <link rel="stylesheet" href="style.css">
    <style>
        .container {
            max-width: 1200px;
            margin: 50px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        /* 产出率样式 */
        .production-rate {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-weight: bold;
        }

        .good-rate {
            background-color: #2ecc71;
            color: white;
        }

        .warning-rate {
            background-color: #f39c12;
            color: white;
        }

        .bad-rate {
            background-color: #e74c3c;
            color: white;
        }

        /* 状态标签样式 */
        .status-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            font-weight: bold;
            text-align: center;
            color: white;
        }

        .planned {
            background-color: #f1c40f;
            color: #000;
        }

        .in_progress {
            background-color: #3498db;
        }

        .completed {
            background-color: #2ecc71;
        }

        .quality_check {
            background-color: #9b59b6;
        }

        .stocked {
            background-color: #27ae60;
        }

        .cancelled {
            background-color: #e74c3c;
        }

        /* 简单标签页样式 */
        .simple-tabs {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #ddd;
        }

        .tab-btn {
            padding: 10px 15px;
            background: #f5f5f5;
            border: 1px solid #ddd;
            border-bottom: none;
            margin-right: 5px;
            border-radius: 5px 5px 0 0;
            cursor: pointer;
        }

        .tab-btn.active {
            background: #fff;
            border-bottom: 1px solid #fff;
            margin-bottom: -1px;
            font-weight: bold;
        }

        /* 链接按钮样式 */
        .btn-link {
            color: #fff;
            text-decoration: none;
            padding: 5px 10px;
            border-radius: 4px;
            margin-right: 5px;
            display: inline-block;
            background-color: #3498db;
            border: 1px solid #2980b9;
            font-size: 12px;
        }

        .btn-link:hover {
            background-color: #2980b9;
        }

        /* 按钮颜色变体 */
        .btn-success {
            background-color: #2ecc71;
            border-color: #27ae60;
        }

        .btn-success:hover {
            background-color: #27ae60;
        }

        .btn-danger {
            background-color: #e74c3c;
            border-color: #c0392b;
        }

        .btn-danger:hover {
            background-color: #c0392b;
        }

        .btn-warning {
            background-color: #f39c12;
            border-color: #d35400;
        }

        .btn-warning:hover {
            background-color: #d35400;
        }

        /* 产量记录模态框样式 */
        .production-modal {
            display: none;
            position: fixed;
            z-index: 1000;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5);
        }

        .modal-content {
            position: relative;
            background-color: #fff;
            margin: 5% auto;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            width: 80%;
            max-width: 600px;
        }

        .close {
            position: absolute;
            right: 15px;
            top: 10px;
            font-size: 24px;
            font-weight: bold;
            cursor: pointer;
        }

        /* 信息盒子样式 */
        .info-box {
            background-color: #f8f9fa;
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 20px;
        }

        .info-box p {
            margin: 5px 0;
        }

        .table-container {
            width: 100%;
            overflow-x: auto;
        }

        table {
            width: auto;
            min-width: 100%;
        }

        th,
        td {
            white-space: nowrap;
            padding: 8px;
        }

        .plan-actions {
            display: flex;
            flex-direction: column;
            align-items: flex-start;
        }

        .plan-actions a {
            display: block;
            margin-bottom: 5px;
            white-space: nowrap;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>
            <?php if ($plan): ?>
                生产计划 <?= htmlspecialchars($plan['plan_number']) ?> - 批次管理
            <?php else: ?>
                加工批次管理
            <?php endif; ?>
        </h2>

        <?php if ($plan): ?>
            <div class="info-box">
                <p><strong>产品:</strong> <?= htmlspecialchars($plan['product_name']) ?> (<?= $plan['product_type'] == 'semi-finished' ? '半成品' : '成品' ?>)</p>
                <p><strong>计划数量:</strong> <?= number_format($plan['quantity_planned'], 2) ?> <?= htmlspecialchars($plan['unit']) ?></p>
                <p><strong>计划状态:</strong> <span class="status-tag <?= $plan['status'] ?>"><?= getStatusName($plan['status']) ?></span></p>
            </div>
        <?php endif; ?>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <div class="simple-tabs">
            <div class="tab-btn active" onclick="showTab('batch-list')">批次列表</div>
            <div class="tab-btn" onclick="showTab('create-batch')">创建新批次</div>
            <?php if ($plan): ?>
                <a href="production_plans.php" class="tab-btn">返回计划列表</a>
            <?php endif; ?>
        </div>

        <!-- 批次列表 -->
        <div id="batch-list" class="tab-content">
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>批次编号</th>
                            <th>计划编号</th>
                            <th>产品</th>
                            <th>计划数量</th>
                            <th>实际产量</th>
                            <th>产出率</th>
                            <th>开始时间</th>
                            <th>结束时间</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($batches)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无批次数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($batches as $batch): ?>
                                <?php
                                // 计算产出率
                                $productionRate = null;
                                $rateClass = '';
                                if ($batch['quantity_produced'] !== null && $batch['quantity_planned'] > 0) {
                                    $productionRate = ($batch['quantity_produced'] / $batch['quantity_planned']) * 100;
                                    if ($productionRate >= 95) {
                                        $rateClass = 'good-rate';
                                    } elseif ($productionRate >= 85) {
                                        $rateClass = 'warning-rate';
                                    } else {
                                        $rateClass = 'bad-rate';
                                    }
                                }
                                ?>
                                <tr>
                                    <td><?= htmlspecialchars($batch['batch_number']) ?></td>
                                    <td><?= htmlspecialchars($batch['plan_number'] ?? '-') ?></td>
                                    <td>
                                        <?= htmlspecialchars($batch['product_name']) ?>
                                        (<?= $batch['product_type'] == 'semi-finished' ? '半成品' : '成品' ?>)
                                    </td>
                                    <td><?= number_format($batch['quantity_planned'], 2) ?> <?= htmlspecialchars($batch['unit']) ?></td>
                                    <td><?= $batch['quantity_produced'] !== null ? number_format($batch['quantity_produced'], 2) . ' ' . htmlspecialchars($batch['unit']) : '-' ?></td>
                                    <td>
                                        <?php if ($productionRate !== null): ?>
                                            <span class="production-rate <?= $rateClass ?>">
                                                <?= number_format($productionRate, 1) ?>%
                                            </span>
                                        <?php else: ?>
                                            -
                                        <?php endif; ?>
                                    </td>
                                    <td><?= $batch['start_time'] ? date('Y-m-d H:i', strtotime($batch['start_time'])) : '-' ?></td>
                                    <td><?= $batch['end_time'] ? date('Y-m-d H:i', strtotime($batch['end_time'])) : '-' ?></td>
                                    <td>
                                        <span class="status-tag <?= $batch['status'] ?>"><?= getStatusName($batch['status']) ?></span>
                                    </td>
                                    <td class="plan-actions">
                                        <?php if ($batch['status'] === 'planned'): ?>
                                            <a href="?plan_id=<?php echo $batch['plan_id']; ?>&action=start&batch_id=<?php echo $batch['id']; ?>" class="btn-link">开始生产</a>
                                        <?php elseif ($batch['status'] === 'in_progress'): ?>
                                            <a href="#" onclick="showProductionModal(<?php echo $batch['id']; ?>)" class="btn-link btn-warning">记录产量</a>
                                            <a href="?plan_id=<?php echo $batch['plan_id']; ?>&action=complete&batch_id=<?php echo $batch['id']; ?>" class="btn-link btn-success">完成生产</a>
                                        <?php elseif ($batch['status'] === 'completed'): ?>
                                            <a href="?plan_id=<?php echo $batch['plan_id']; ?>&action=quality_check&batch_id=<?php echo $batch['id']; ?>" class="btn-link btn-warning">送检</a>
                                        <?php elseif ($batch['status'] === 'quality_check'): ?>
                                            <a href="?plan_id=<?php echo $batch['plan_id']; ?>&action=stock&batch_id=<?php echo $batch['id']; ?>" class="btn-link btn-success">入库</a>
                                        <?php endif; ?>

                                        <?php if (in_array($batch['status'], ['planned', 'in_progress'])): ?>
                                            <a href="?plan_id=<?php echo $batch['plan_id']; ?>&action=cancel&batch_id=<?php echo $batch['id']; ?>" class="btn-link btn-danger">取消</a>
                                        <?php endif; ?>

                                        <?php if ($batch['quantity_produced'] !== null): ?>
                                            <a href="#" onclick="showProductionModal(<?php echo $batch['id']; ?>)" class="btn-link btn-warning">更新产量</a>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- 创建新批次表单 -->
        <div id="create-batch" class="tab-content" style="display: none;">
            <div class="form-container">
                <h3>创建新生产批次</h3>
                <form method="POST" action="batch_management.php<?= $plan_id ? "?plan_id=$plan_id" : "" ?>">
                    <?= csrf_field() ?>
                    <input type="hidden" name="action" value="create_batch">

                    <div class="form-group">
                        <label>批次编号</label>
                        <input type="text" name="batch_number" value="<?= htmlspecialchars($newBatchNumber) ?>" readonly>
                        <small>系统自动生成</small>
                    </div>

                    <div class="form-group">
                        <label>关联生产计划</label>
                        <?php if ($plan): ?>
                            <input type="text" value="<?= htmlspecialchars($plan['plan_number']) ?>" readonly>
                            <input type="hidden" name="production_plan_id" value="<?= $plan['id'] ?>">
                            <input type="hidden" name="product_id" value="<?= $plan['product_id'] ?>">
                        <?php else: ?>
                            <select name="production_plan_id">
                                <option value="">-- 可选，不关联计划 --</option>
                                <?php
                                $plans = $pdo->query("
                                    SELECT pp.id, pp.plan_number, p.name AS product_name
                                    FROM production_plans pp
                                    JOIN products p ON pp.product_id = p.id
                                    WHERE pp.status IN ('planned', 'in_progress')
                                    ORDER BY pp.plan_date DESC
                                ")->fetchAll();

                                foreach ($plans as $p):
                                ?>
                                    <option value="<?= $p['id'] ?>"><?= htmlspecialchars($p['plan_number']) ?> - <?= htmlspecialchars($p['product_name']) ?></option>
                                <?php endforeach; ?>
                            </select>
                        <?php endif; ?>
                    </div>

                    <?php if (!$plan): ?>
                        <div class="form-group">
                            <label>产品</label>
                            <select name="product_id" required>
                                <option value="">-- 请选择产品 --</option>
                                <optgroup label="半成品">
                                    <?php foreach ($products as $product): ?>
                                        <?php if ($product['type'] === 'semi-finished'): ?>
                                            <option value="<?= $product['id'] ?>">
                                                <?= htmlspecialchars($product['name']) ?>
                                                (<?= htmlspecialchars($product['specification'] ?? '-') ?>)
                                            </option>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </optgroup>
                                <optgroup label="成品">
                                    <?php foreach ($products as $product): ?>
                                        <?php if ($product['type'] === 'finished'): ?>
                                            <option value="<?= $product['id'] ?>">
                                                <?= htmlspecialchars($product['name']) ?>
                                                (<?= htmlspecialchars($product['specification'] ?? '-') ?>)
                                            </option>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </optgroup>
                            </select>
                        </div>
                    <?php endif; ?>

                    <div class="form-group">
                        <label>计划生产数量</label>
                        <?php if ($plan): ?>
                            <input type="number" name="quantity_planned" step="0.01" min="0.01" value="<?= $plan['quantity_planned'] ?>" required>
                        <?php else: ?>
                            <input type="number" name="quantity_planned" step="0.01" min="0.01" required>
                        <?php endif; ?>
                    </div>

                    <div class="form-group">
                        <label>预计开始时间 (可选)</label>
                        <input type="datetime-local" name="start_time">
                    </div>

                    <div class="form-group">
                        <label>预计结束时间 (可选)</label>
                        <input type="datetime-local" name="end_time">
                    </div>

                    <div class="form-group">
                        <label>状态</label>
                        <select name="status" required>
                            <option value="planned">已计划</option>
                            <option value="in_progress">生产中</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>预计成本 (可选)</label>
                        <input type="number" name="estimated_cost" step="0.01" min="0">
                    </div>

                    <div class="form-group">
                        <label>备注 (可选)</label>
                        <textarea name="notes" rows="4"></textarea>
                    </div>

                    <button type="submit" class="btn-link">创建批次</button>
                </form>
            </div>
        </div>

        <!-- 记录产量模态框 -->
        <div id="productionModal" class="production-modal">
            <div class="modal-content">
                <span class="close" onclick="closeProductionModal()">&times;</span>
                <h3>记录实际产量</h3>
                <p id="batch-info"></p>

                <form method="POST" action="batch_management.php<?= $plan_id ? "?plan_id=$plan_id" : "" ?>">
                    <?= csrf_field() ?>
                    <input type="hidden" name="action" value="update_production">
                    <input type="hidden" name="batch_id" id="batch_id">

                    <div class="form-group">
                        <label>实际产量</label>
                        <input type="number" name="quantity_produced" id="quantity_produced" step="0.01" min="0" required>
                        <small>计划生产量: <span id="planned-quantity"></span></small>
                    </div>

                    <div class="form-group">
                        <label>实际成本 (可选)</label>
                        <input type="number" name="actual_cost" id="actual_cost" step="0.01" min="0">
                    </div>

                    <button type="submit" class="btn-link btn-success">保存产量信息</button>
                </form>
            </div>
        </div>
    </div>

    <script>
        // 标签页切换函数
        function showTab(tabId) {
            // 隐藏所有标签内容
            document.querySelectorAll('.tab-content').forEach(tab => {
                tab.style.display = 'none';
            });

            // 显示选中的标签内容
            document.getElementById(tabId).style.display = 'block';

            // 更新标签按钮样式
            document.querySelectorAll('.tab-btn').forEach(btn => {
                btn.classList.remove('active');
            });

            // 找到对应的按钮并设为活动状态
            document.querySelector(`.tab-btn[onclick="showTab('${tabId}')"]`).classList.add('active');
        }

        // 打开产量记录模态框
        function showProductionModal(batchId) {
            document.getElementById('batch_id').value = batchId;
            document.getElementById('productionModal').style.display = 'block';

            // 这里应该有获取批次信息的AJAX请求，简化处理
            // 实际项目中应通过AJAX获取批次的详细信息
        }

        // 关闭产量记录模态框
        function closeProductionModal() {
            document.getElementById('productionModal').style.display = 'none';
        }

        // 点击模态框外部关闭模态框
        window.onclick = function(event) {
            const modal = document.getElementById('productionModal');
            if (event.target === modal) {
                modal.style.display = 'none';
            }
        }
    </script>
</body>

</html>