<?php
// quality/material_inspection.php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取原材料质检记录列表
$inspections = [];
try {
    $stmt = $pdo->prepare("
        SELECT mr.id, mr.received_date, mr.batch_number, p.name AS product_name, 
            mr.received_quantity, mr.quality_check_result, mr.inspection_notes,
            u.username AS inspector_name
        FROM material_receiving mr
        JOIN products p ON mr.product_id = p.id
        LEFT JOIN users u ON mr.inspector_id = u.id
        WHERE p.type = 'raw'
        ORDER BY mr.received_date DESC
        LIMIT 50
    ");
    $stmt->execute();
    $inspections = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "数据库错误: " . $e->getMessage();
}

// 处理质检结果更新
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'update_inspection') {
    $inspection_id = $_POST['inspection_id'] ?? 0;
    $quality_result = $_POST['quality_result'] ?? '';
    $inspection_notes = $_POST['inspection_notes'] ?? '';

    if ($inspection_id && $quality_result) {
        try {
            $stmt = $pdo->prepare("
                UPDATE material_receiving 
                SET quality_check_result = :result, 
                    inspection_notes = :notes,
                    inspector_id = :inspector_id
                WHERE id = :id
            ");
            $stmt->execute([
                ':result' => $quality_result,
                ':notes' => $inspection_notes,
                ':inspector_id' => $_SESSION['user_id'],
                ':id' => $inspection_id
            ]);

            $_SESSION['success'] = "质检结果已更新";
            header("Location: material_inspection.php");
            exit;
        } catch (PDOException $e) {
            $error = "更新失败: " . $e->getMessage();
        }
    } else {
        $error = "请提供所有必要信息";
    }
}

// 获取质检项目列表
$inspectionItems = [
    '农药残留检测' => ['标准值范围' => '< 0.05 mg/kg', '检测方法' => '气相色谱法'],
    '水分含量检测' => ['标准值范围' => '60% - 80%', '检测方法' => '烘干法'],
    '重金属检测' => ['标准值范围' => '< 0.01 mg/kg', '检测方法' => '分光光度法'],
    '微生物检测' => ['标准值范围' => '< 1000 CFU/g', '检测方法' => '平板计数法'],
    '感官检查' => ['标准值范围' => '色泽鲜艳，无腐烂，无异味', '检测方法' => '人工检测']
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>原材料质检 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .inspection-stats {
            display: flex;
            justify-content: space-between;
            margin-bottom: 20px;
        }

        .stat-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 15px;
            width: 32%;
            text-align: center;
        }

        .stat-value {
            font-size: 24px;
            font-weight: bold;
            margin: 10px 0;
        }

        .stat-label {
            font-size: 14px;
            color: #666;
        }

        .passed {
            color: #2ecc71;
        }

        .failed {
            color: #e74c3c;
        }

        .pending {
            color: #f39c12;
        }

        .inspection-tabs {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #ddd;
        }

        .tab-button {
            padding: 10px 20px;
            background: none;
            border: none;
            cursor: pointer;
            font-size: 16px;
            border-bottom: 3px solid transparent;
            transition: all 0.3s;
        }

        .tab-button.active {
            border-bottom-color: #3498db;
            color: #3498db;
            font-weight: bold;
        }

        .tab-button:hover:not(.active) {
            border-bottom-color: #bdc3c7;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .quality-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            font-weight: bold;
            color: white;
        }

        .quality-passed {
            background-color: #2ecc71;
        }

        .quality-failed {
            background-color: #e74c3c;
        }

        .quality-pending {
            background-color: #f39c12;
        }

        .inspection-form {
            background-color: #f9f9f9;
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 20px;
        }

        .form-row {
            display: flex;
            margin-bottom: 15px;
        }

        .form-group {
            flex: 1;
            margin-right: 15px;
        }

        .form-group:last-child {
            margin-right: 0;
        }

        .checkbox-list {
            list-style: none;
            padding: 0;
        }

        .checkbox-item {
            margin-bottom: 10px;
        }

        .standards-table {
            margin-top: 20px;
        }

    </style>
</head>

<body>
    <div class="container">
        <h2>原材料质检管理</h2>

        <?php if (isset($error)): ?>
            <div class="alert alert-error"><?= $error ?></div>
        <?php endif; ?>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <!-- 统计卡片 -->
        <div class="inspection-stats">
            <?php
            $passedCount = 0;
            $failedCount = 0;
            $pendingCount = 0;

            foreach ($inspections as $inspection) {
                if ($inspection['quality_check_result'] === 'passed') {
                    $passedCount++;
                } elseif ($inspection['quality_check_result'] === 'failed') {
                    $failedCount++;
                } else {
                    $pendingCount++;
                }
            }
            $totalCount = count($inspections);
            $passRate = $totalCount > 0 ? round(($passedCount / $totalCount) * 100, 1) : 0;
            ?>
            <div class="stat-card">
                <div class="stat-value passed"><?= $passedCount ?></div>
                <div class="stat-label">通过检验批次</div>
            </div>
            <div class="stat-card">
                <div class="stat-value failed"><?= $failedCount ?></div>
                <div class="stat-label">不合格批次</div>
            </div>
            <div class="stat-card">
                <div class="stat-value"><?= $passRate ?>%</div>
                <div class="stat-label">原料合格率</div>
            </div>
        </div>

        <!-- 标签页 -->
        <div class="inspection-tabs">
            <button class="tab-button active" onclick="showTab('pending-tab')">待检验批次</button>
            <button class="tab-button" onclick="showTab('all-tab')">全部质检记录</button>
            <button class="tab-button" onclick="showTab('standards-tab')">质检标准</button>
        </div>

        <!-- 待检验批次 -->
        <div id="pending-tab" class="tab-content active">
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>批次号</th>
                            <th>原材料名称</th>
                            <th>接收日期</th>
                            <th>数量</th>
                            <th>质检状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $hasPending = false;
                        foreach ($inspections as $inspection):
                            if ($inspection['quality_check_result'] === 'pending'):
                                $hasPending = true;
                        ?>
                                <tr>
                                    <td><?= htmlspecialchars($inspection['batch_number']) ?></td>
                                    <td><?= htmlspecialchars($inspection['product_name']) ?></td>
                                    <td><?= date('Y-m-d', strtotime($inspection['received_date'])) ?></td>
                                    <td><?= number_format($inspection['received_quantity'], 2) ?></td>
                                    <td>
                                        <span class="quality-tag quality-pending">待检验</span>
                                    </td>
                                    <td>
                                        <button onclick="showInspectionForm(<?= $inspection['id'] ?>, '<?= htmlspecialchars($inspection['batch_number']) ?>', '<?= htmlspecialchars($inspection['product_name']) ?>')" class="btn-link">
                                            进行质检
                                        </button>
                                    </td>
                                </tr>
                        <?php endif;
                        endforeach; ?>

                        <?php if (!$hasPending): ?>
                            <tr>
                                <td colspan="6" class="text-center">当前没有待检验的批次</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 质检表单 (默认隐藏) -->
            <div id="inspection-form" class="inspection-form" style="display: none;">
                <h3>质检录入 - <span id="batch-info"></span></h3>
                <form method="POST" action="material_inspection.php">
                    <input type="hidden" name="action" value="update_inspection">
                    <input type="hidden" name="inspection_id" id="inspection_id">

                    <div class="form-row">
                        <div class="form-group">
                            <label>质检结果</label>
                            <select name="quality_result" class="form-control" required>
                                <option value="">-- 请选择 --</option>
                                <option value="passed">通过</option>
                                <option value="failed">不合格</option>
                            </select>
                        </div>
                    </div>

                    <div class="form-group">
                        <label>质检项目</label>
                        <ul class="checkbox-list">
                            <?php foreach ($inspectionItems as $item => $details): ?>
                                <li class="checkbox-item">
                                    <label>
                                        <input type="checkbox" name="inspection_items[]" value="<?= $item ?>">
                                        <?= $item ?> (<?= $details['标准值范围'] ?>)
                                    </label>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    </div>

                    <div class="form-group">
                        <label>检验备注</label>
                        <textarea name="inspection_notes" class="form-control" rows="4" placeholder="输入检验结果详情、异常情况说明等..."></textarea>
                    </div>

                    <div class="form-group">
                        <button type="submit" class="btn-primary">提交质检结果</button>
                        
                    </div>
                    <div>
                        <button type="button" onclick="hideInspectionForm()" class="btn-cancel">取消</button>
                    </div>
                </form>
            </div>
        </div>

        <!-- 全部质检记录 -->
        <div id="all-tab" class="tab-content">
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>批次号</th>
                            <th>原材料名称</th>
                            <th>接收日期</th>
                            <th>数量</th>
                            <th>质检结果</th>
                            <th>检验员</th>
                            <th>备注</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($inspections)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无质检记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($inspections as $inspection): ?>
                                <?php
                                $statusClass = '';
                                $statusText = '';

                                if ($inspection['quality_check_result'] === 'passed') {
                                    $statusClass = 'quality-passed';
                                    $statusText = '合格';
                                } elseif ($inspection['quality_check_result'] === 'failed') {
                                    $statusClass = 'quality-failed';
                                    $statusText = '不合格';
                                } else {
                                    $statusClass = 'quality-pending';
                                    $statusText = '待检验';
                                }
                                ?>
                                <tr>
                                    <td><?= htmlspecialchars($inspection['batch_number']) ?></td>
                                    <td><?= htmlspecialchars($inspection['product_name']) ?></td>
                                    <td><?= date('Y-m-d', strtotime($inspection['received_date'])) ?></td>
                                    <td><?= number_format($inspection['received_quantity'], 2) ?></td>
                                    <td><span class="quality-tag <?= $statusClass ?>"><?= $statusText ?></span></td>
                                    <td><?= $inspection['inspector_name'] ?: '-' ?></td>
                                    <td><?= htmlspecialchars($inspection['inspection_notes'] ?: '-') ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- 质检标准 -->
        <div id="standards-tab" class="tab-content">
            <div class="standards-table">
                <table>
                    <thead>
                        <tr>
                            <th>检测项目</th>
                            <th>标准值范围</th>
                            <th>检测方法</th>
                            <th>适用原料</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($inspectionItems as $item => $details): ?>
                            <tr>
                                <td><?= htmlspecialchars($item) ?></td>
                                <td><?= htmlspecialchars($details['标准值范围']) ?></td>
                                <td><?= htmlspecialchars($details['检测方法']) ?></td>
                                <td>所有原料</td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <script>
        // 显示选定的标签页
        function showTab(tabId) {
            // 隐藏所有标签内容
            document.querySelectorAll('.tab-content').forEach(tab => {
                tab.classList.remove('active');
            });

            // 移除所有标签按钮的激活状态
            document.querySelectorAll('.tab-button').forEach(button => {
                button.classList.remove('active');
            });

            // 激活选定的标签
            document.getElementById(tabId).classList.add('active');

            // 激活对应的按钮
            event.currentTarget.classList.add('active');
        }

        // 显示质检表单
        function showInspectionForm(id, batchNumber, productName) {
            document.getElementById('inspection_id').value = id;
            document.getElementById('batch-info').textContent = `${batchNumber} (${productName})`;
            document.getElementById('inspection-form').style.display = 'block';

            // 滚动到表单位置
            document.getElementById('inspection-form').scrollIntoView({
                behavior: 'smooth'
            });
        }

        // 隐藏质检表单
        function hideInspectionForm() {
            document.getElementById('inspection-form').style.display = 'none';
        }
    </script>
</body>

</html>