<?php
// quality/production_monitoring.php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 检查是否需要创建监控数据表
try {
    // 创建生产过程监控表（如果不存在）
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `production_monitoring` (
          `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '监控记录ID',
          `batch_id` INT UNSIGNED NOT NULL COMMENT '生产批次ID',
          `process_step` ENUM('水果清洗', '腌制', '烘干', '包装') NOT NULL COMMENT '生产步骤',
          `temperature` DECIMAL(5, 2) DEFAULT NULL COMMENT '温度记录 (℃)',
          `humidity` DECIMAL(5, 2) DEFAULT NULL COMMENT '湿度记录 (%)',
          `time_elapsed` INT UNSIGNED DEFAULT NULL COMMENT '已用时间 (分钟)',
          `time_remaining` INT UNSIGNED DEFAULT NULL COMMENT '剩余时间 (分钟)',
          `status` ENUM('normal', 'warning', 'critical') NOT NULL DEFAULT 'normal' COMMENT '状态',
          `notes` TEXT DEFAULT NULL COMMENT '备注',
          `recorded_by` INT UNSIGNED DEFAULT NULL COMMENT '记录人员ID',
          `recorded_at` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '记录时间',
          PRIMARY KEY (`id`),
          KEY `idx_monitoring_batch` (`batch_id`),
          KEY `idx_monitoring_step` (`process_step`),
          KEY `idx_monitoring_status` (`status`),
          KEY `idx_monitoring_time` (`recorded_at`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='生产过程监控记录表'
    ");
} catch (PDOException $e) {
    $error = "数据库错误: " . $e->getMessage();
}

// 获取当前正在进行中的批次列表
$activeBatches = [];
try {
    $stmt = $pdo->prepare("
        SELECT pb.id, pb.batch_number, pb.start_time, p.name AS product_name, 
               p.type AS product_type, pb.status
        FROM production_batches pb
        JOIN products p ON pb.product_id = p.id
        WHERE pb.status = 'in_progress'
        ORDER BY pb.start_time DESC
    ");
    $stmt->execute();
    $activeBatches = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取批次数据失败: " . $e->getMessage();
}

// 处理监控数据添加请求
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'add_monitoring') {
    $batch_id = $_POST['batch_id'] ?? 0;
    $process_step = $_POST['process_step'] ?? '';
    $temperature = $_POST['temperature'] ?? null;
    $humidity = $_POST['humidity'] ?? null;
    $time_elapsed = $_POST['time_elapsed'] ?? null;
    $time_remaining = $_POST['time_remaining'] ?? null;
    $notes = $_POST['notes'] ?? '';

    // 根据参数计算状态
    $status = 'normal';
    if (($process_step === '腌制' && $temperature > 30) ||
        ($process_step === '烘干' && $temperature < 50) ||
        ($process_step === '腌制' && $humidity < 60) ||
        ($process_step === '腌制' && $time_elapsed > 240)
    ) {
        $status = 'warning';
    }
    if (($process_step === '腌制' && $temperature > 35) ||
        ($process_step === '烘干' && $temperature < 40) ||
        ($process_step === '腌制' && $humidity < 50) ||
        ($process_step === '腌制' && $time_elapsed > 300)
    ) {
        $status = 'critical';
    }

    try {
        $stmt = $pdo->prepare("
            INSERT INTO production_monitoring 
            (batch_id, process_step, temperature, humidity, time_elapsed, time_remaining, status, notes, recorded_by)
            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $batch_id,
            $process_step,
            $temperature,
            $humidity,
            $time_elapsed,
            $time_remaining,
            $status,
            $notes,
            $_SESSION['user_id']
        ]);

        $_SESSION['success'] = "监控数据已记录";

        // 如果状态是严重或警告，添加日志
        if ($status !== 'normal') {
            $stmt = $pdo->prepare("
                INSERT INTO activity_log 
                (user_id, username, action, target_type, target_id, details, ip_address) 
                VALUES (?, ?, ?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $_SESSION['user_id'],
                $_SESSION['username'],
                $status === 'critical' ? '生产过程严重异常' : '生产过程警告',
                'production_batch',
                $batch_id,
                json_encode([
                    'process_step' => $process_step,
                    'temperature' => $temperature,
                    'humidity' => $humidity,
                    'time_elapsed' => $time_elapsed,
                    'notes' => $notes
                ]),
                $_SERVER['REMOTE_ADDR']
            ]);
        }

        header("Location: production_monitoring.php");
        exit;
    } catch (PDOException $e) {
        $error = "添加监控数据失败: " . $e->getMessage();
    }
}

// 获取选定批次的监控记录
$batchId = $_GET['batch_id'] ?? null;
$monitoringData = [];

if ($batchId) {
    try {
        $stmt = $pdo->prepare("
            SELECT pm.*, u.username AS recorder_name, pb.batch_number
            FROM production_monitoring pm
            JOIN users u ON pm.recorded_by = u.id
            JOIN production_batches pb ON pm.batch_id = pb.id
            WHERE pm.batch_id = ?
            ORDER BY pm.recorded_at DESC
            LIMIT 100
        ");
        $stmt->execute([$batchId]);
        $monitoringData = $stmt->fetchAll();

        // 获取批次信息
        $stmt = $pdo->prepare("
            SELECT pb.batch_number, p.name AS product_name
            FROM production_batches pb
            JOIN products p ON pb.product_id = p.id
            WHERE pb.id = ?
        ");
        $stmt->execute([$batchId]);
        $batchInfo = $stmt->fetch();
    } catch (PDOException $e) {
        $error = "获取监控数据失败: " . $e->getMessage();
    }
}

// 获取不同工艺步骤的参考标准
$processStandards = [
    '水果清洗' => [
        '温度' => '15-25℃',
        '湿度' => '不适用',
        '时间' => '15-30分钟'
    ],
    '腌制' => [
        '温度' => '20-30℃',
        '湿度' => '60-80%',
        '时间' => '180-240分钟(3-4小时)'
    ],
    '烘干' => [
        '温度' => '50-70℃',
        '湿度' => '30-50%',
        '时间' => '120-360分钟(2-6小时)'
    ],
    '包装' => [
        '温度' => '18-25℃',
        '湿度' => '30-50%',
        '时间' => '30-60分钟'
    ]
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>生产过程监控 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .monitoring-container {
            margin-bottom: 30px;
        }

        .monitor-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            padding: 20px;
            margin-bottom: 20px;
        }

        .parameter-group {
            display: flex;
            flex-wrap: wrap;
            margin-bottom: 20px;
        }

        .parameter-card {
            background-color: #f9f9f9;
            border-radius: 8px;
            padding: 15px;
            margin-right: 15px;
            margin-bottom: 15px;
            width: calc(25% - 15px);
            text-align: center;
        }

        .parameter-value {
            font-size: 24px;
            font-weight: bold;
            margin: 10px 0;
        }

        .parameter-label {
            font-size: 14px;
            color: #666;
        }

        .parameter-card.temperature {
            border-left: 4px solid #e74c3c;
        }

        .parameter-card.humidity {
            border-left: 4px solid #3498db;
        }

        .parameter-card.time {
            border-left: 4px solid #f39c12;
        }

        .parameter-card.status {
            border-left: 4px solid #2ecc71;
        }

        .monitor-filters {
            display: flex;
            margin-bottom: 20px;
        }

        .filter-item {
            margin-right: 15px;
        }

        .monitoring-tabs {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #ddd;
        }

        .tab-button {
            padding: 10px 20px;
            background: none;
            border: none;
            cursor: pointer;
            font-size: 16px;
            border-bottom: 3px solid transparent;
            transition: all 0.3s;
        }

        .tab-button.active {
            border-bottom-color: #e74c3c;
            color: #e74c3c;
            font-weight: bold;
        }

        .tab-button:hover:not(.active) {
            border-bottom-color: #bdc3c7;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .monitoring-form {
            background-color: #f9f9f9;
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 20px;
        }

        .form-row {
            display: flex;
            flex-wrap: wrap;
            margin-bottom: 15px;
        }

        .form-group {
            flex: 1;
            min-width: 200px;
            margin-right: 15px;
            margin-bottom: 15px;
        }

        .form-group:last-child {
            margin-right: 0;
        }

        .status-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            font-weight: bold;
            color: white;
        }

        .status-normal {
            background-color: #2ecc71;
        }

        .status-warning {
            background-color: #f39c12;
        }

        .status-critical {
            background-color: #e74c3c;
        }

        .process-standards {
            margin-top: 20px;
        }

        .standards-table td:nth-child(1) {
            font-weight: bold;
        }

        .chart-container {
            height: 300px;
            margin-bottom: 30px;
        }

        .btn-monitor {
            background-color: #e74c3c;
            color: white;
            border: none;
            padding: 8px 15px;
            border-radius: 4px;
            cursor: pointer;
        }

        .btn-monitor:hover {
            background-color: #c0392b;
        }

        .batch-selector {
            margin-bottom: 20px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>生产过程监控</h2>

        <?php if (isset($error)): ?>
            <div class="alert alert-error"><?= $error ?></div>
        <?php endif; ?>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <!-- 批次选择 -->
        <div class="batch-selector">
            <form method="get" action="production_monitoring.php" class="form-row">
                <div class="form-group">
                    <label>选择生产批次</label>
                    <select name="batch_id" class="form-control" onchange="this.form.submit()">
                        <option value="">-- 请选择批次 --</option>
                        <?php foreach ($activeBatches as $batch): ?>
                            <option value="<?= $batch['id'] ?>" <?= $batchId == $batch['id'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($batch['batch_number']) ?> - <?= htmlspecialchars($batch['product_name']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </form>
        </div>

        <?php if (empty($activeBatches)): ?>
            <div class="alert alert-info">当前没有进行中的生产批次，请先在生产计划中启动批次。</div>
        <?php elseif ($batchId): ?>
            <!-- 监控标签页 -->
            <div class="monitoring-tabs">
                <button class="tab-button active" onclick="showTab('monitoring-tab')">实时监控</button>
                <button class="tab-button" onclick="showTab('history-tab')">历史记录</button>
                <button class="tab-button" onclick="showTab('standards-tab')">工艺标准</button>
            </div>

            <!-- 实时监控标签内容 -->
            <div id="monitoring-tab" class="tab-content active">
                <!-- 监控表单 -->
                <div class="monitoring-form">
                    <h3>添加监控记录 - <?= htmlspecialchars($batchInfo['batch_number'] ?? '') ?></h3>
                    <form method="POST" action="production_monitoring.php">
                        <input type="hidden" name="action" value="add_monitoring">
                        <input type="hidden" name="batch_id" value="<?= $batchId ?>">

                        <div class="form-row">
                            <div class="form-group">
                                <label>生产步骤</label>
                                <select name="process_step" class="form-control" required onchange="updateStandards(this.value)">
                                    <option value="">-- 请选择 --</option>
                                    <option value="水果清洗">水果清洗</option>
                                    <option value="腌制">腌制</option>
                                    <option value="烘干">烘干</option>
                                    <option value="包装">包装</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label>温度 (℃)</label>
                                <input type="number" name="temperature" class="form-control" step="0.1" min="-10" max="100" required>
                                <small id="temp-standard"></small>
                            </div>

                            <div class="form-group">
                                <label>湿度 (%)</label>
                                <input type="number" name="humidity" class="form-control" step="0.1" min="0" max="100">
                                <small id="humidity-standard"></small>
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-group">
                                <label>已用时间 (分钟)</label>
                                <input type="number" name="time_elapsed" class="form-control" min="0" required>
                                <small id="time-standard"></small>
                            </div>

                            <div class="form-group">
                                <label>剩余时间 (分钟)</label>
                                <input type="number" name="time_remaining" class="form-control" min="0">
                            </div>

                            <div class="form-group">
                                <label>备注</label>
                                <textarea name="notes" class="form-control" rows="2"></textarea>
                            </div>
                        </div>

                        <div class="form-group">
                            <button type="submit" class="btn-monitor">记录监控数据</button>
                        </div>
                    </form>
                </div>

                <!-- 最新监控数据卡片 -->
                <?php if (!empty($monitoringData)): ?>
                    <div class="monitor-card">
                        <h3>最新监控数据</h3>
                        <div class="parameter-group">
                            <div class="parameter-card temperature">
                                <div class="parameter-value"><?= $monitoringData[0]['temperature'] ?? '-' ?> ℃</div>
                                <div class="parameter-label">温度</div>
                            </div>

                            <div class="parameter-card humidity">
                                <div class="parameter-value"><?= $monitoringData[0]['humidity'] ?? '-' ?> %</div>
                                <div class="parameter-label">湿度</div>
                            </div>

                            <div class="parameter-card time">
                                <div class="parameter-value"><?= $monitoringData[0]['time_elapsed'] ?? '-' ?> 分钟</div>
                                <div class="parameter-label">已用时间</div>
                            </div>

                            <div class="parameter-card status">
                                <?php
                                $statusClass = 'status-normal';
                                $statusText = '正常';

                                if (isset($monitoringData[0]['status'])) {
                                    if ($monitoringData[0]['status'] === 'warning') {
                                        $statusClass = 'status-warning';
                                        $statusText = '警告';
                                    } elseif ($monitoringData[0]['status'] === 'critical') {
                                        $statusClass = 'status-critical';
                                        $statusText = '严重';
                                    }
                                }
                                ?>
                                <div class="parameter-value">
                                    <span class="status-tag <?= $statusClass ?>"><?= $statusText ?></span>
                                </div>
                                <div class="parameter-label">状态</div>
                            </div>
                        </div>

                        <p><strong>当前步骤:</strong> <?= $monitoringData[0]['process_step'] ?? '-' ?></p>
                        <p><strong>记录时间:</strong> <?= isset($monitoringData[0]['recorded_at']) ? date('Y-m-d H:i:s', strtotime($monitoringData[0]['recorded_at'])) : '-' ?></p>
                        <p><strong>记录人员:</strong> <?= $monitoringData[0]['recorder_name'] ?? '-' ?></p>
                        <?php if (isset($monitoringData[0]['notes']) && !empty($monitoringData[0]['notes'])): ?>
                            <p><strong>备注:</strong> <?= htmlspecialchars($monitoringData[0]['notes']) ?></p>
                        <?php endif; ?>
                    </div>
                <?php else: ?>
                    <div class="alert alert-info">该批次暂无监控数据记录，请添加监控数据。</div>
                <?php endif; ?>
            </div>

            <!-- 历史记录标签内容 -->
            <div id="history-tab" class="tab-content">
                <div class="table-container">
                    <table>
                        <thead>
                            <tr>
                                <th>时间</th>
                                <th>步骤</th>
                                <th>温度(℃)</th>
                                <th>湿度(%)</th>
                                <th>已用时间(分钟)</th>
                                <th>剩余时间(分钟)</th>
                                <th>状态</th>
                                <th>记录人员</th>
                                <th>备注</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($monitoringData)): ?>
                                <tr>
                                    <td colspan="9" class="text-center">暂无监控历史记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($monitoringData as $record): ?>
                                    <?php
                                    $statusClass = 'status-normal';
                                    $statusText = '正常';

                                    if ($record['status'] === 'warning') {
                                        $statusClass = 'status-warning';
                                        $statusText = '警告';
                                    } elseif ($record['status'] === 'critical') {
                                        $statusClass = 'status-critical';
                                        $statusText = '严重';
                                    }
                                    ?>
                                    <tr>
                                        <td><?= date('Y-m-d H:i', strtotime($record['recorded_at'])) ?></td>
                                        <td><?= $record['process_step'] ?></td>
                                        <td><?= $record['temperature'] ?></td>
                                        <td><?= $record['humidity'] ?></td>
                                        <td><?= $record['time_elapsed'] ?></td>
                                        <td><?= $record['time_remaining'] ?></td>
                                        <td><span class="status-tag <?= $statusClass ?>"><?= $statusText ?></span></td>
                                        <td><?= $record['recorder_name'] ?></td>
                                        <td><?= htmlspecialchars($record['notes'] ?: '-') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <!-- 工艺标准标签内容 -->
            <div id="standards-tab" class="tab-content">
                <div class="process-standards">
                    <h3>生产过程工艺要求标准</h3>
                    <div class="table-container">
                        <table class="standards-table">
                            <thead>
                                <tr>
                                    <th>生产步骤</th>
                                    <th>温度要求</th>
                                    <th>湿度要求</th>
                                    <th>时间要求</th>
                                    <th>注意事项</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($processStandards as $step => $standards): ?>
                                    <tr>
                                        <td><?= $step ?></td>
                                        <td><?= $standards['温度'] ?></td>
                                        <td><?= $standards['湿度'] ?></td>
                                        <td><?= $standards['时间'] ?></td>
                                        <td>
                                            <?php
                                            switch ($step) {
                                                case '水果清洗':
                                                    echo '确保彻底清洗，避免残留农药和杂质';
                                                    break;
                                                case '腌制':
                                                    echo '保持恒温环境，防止细菌滋生，控制盐分浓度';
                                                    break;
                                                case '烘干':
                                                    echo '均匀受热，避免烘烤过度造成口感变差';
                                                    break;
                                                case '包装':
                                                    echo '干燥环境下操作，防止受潮影响保质期';
                                                    break;
                                            }
                                            ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <h3 class="mt-4">异常情况应对措施</h3>
                    <div class="table-container">
                        <table>
                            <thead>
                                <tr>
                                    <th>异常类型</th>
                                    <th>表现</th>
                                    <th>应对措施</th>
                                </tr>
                            </thead>
                            <tbody>
                                <tr>
                                    <td>温度过高</td>
                                    <td>超过标准上限</td>
                                    <td>立即调低环境温度，增加通风，必要时暂停生产</td>
                                </tr>
                                <tr>
                                    <td>温度过低</td>
                                    <td>低于标准下限</td>
                                    <td>调高环境温度，检查加热设备是否故障</td>
                                </tr>
                                <tr>
                                    <td>湿度异常</td>
                                    <td>超出湿度标准范围</td>
                                    <td>调整除湿/加湿设备，检查密封情况</td>
                                </tr>
                                <tr>
                                    <td>时间过长</td>
                                    <td>超过标准工艺时间</td>
                                    <td>检查是否有工艺障碍，评估产品质量后决定是否继续</td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    </div>

    <script>
        // 显示选定的标签页
        function showTab(tabId) {
            // 隐藏所有标签内容
            document.querySelectorAll('.tab-content').forEach(tab => {
                tab.classList.remove('active');
            });

            // 移除所有标签按钮的激活状态
            document.querySelectorAll('.tab-button').forEach(button => {
                button.classList.remove('active');
            });

            // 激活选定的标签
            document.getElementById(tabId).classList.add('active');

            // 激活对应的按钮
            event.currentTarget.classList.add('active');
        }

        // 根据选择的生产步骤更新显示的标准值
        function updateStandards(step) {
            // 定义各步骤的标准值
            const standards = {
                '水果清洗': {
                    'temp': '15-25℃',
                    'humidity': '不适用',
                    'time': '15-30分钟'
                },
                '腌制': {
                    'temp': '20-30℃',
                    'humidity': '60-80%',
                    'time': '180-240分钟(3-4小时)'
                },
                '烘干': {
                    'temp': '50-70℃',
                    'humidity': '30-50%',
                    'time': '120-360分钟(2-6小时)'
                },
                '包装': {
                    'temp': '18-25℃',
                    'humidity': '30-50%',
                    'time': '30-60分钟'
                }
            };

            // 更新显示的标准值
            if (standards[step]) {
                document.getElementById('temp-standard').textContent = `标准范围: ${standards[step].temp}`;
                document.getElementById('humidity-standard').textContent = `标准范围: ${standards[step].humidity}`;
                document.getElementById('time-standard').textContent = `标准范围: ${standards[step].time}`;
            } else {
                document.getElementById('temp-standard').textContent = '';
                document.getElementById('humidity-standard').textContent = '';
                document.getElementById('time-standard').textContent = '';
            }
        }
    </script>
</body>

</html>