<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取订单ID（如果有）
$order_id = isset($_GET['order_id']) ? (int)$_GET['order_id'] : null;

// 获取所有待入库的采购订单项
if ($order_id) {
    // 如果指定了订单ID，只获取该订单的项目
    try {
        // 获取订单信息
        $stmt = $pdo->prepare("
            SELECT po.id, po.order_number, s.name AS supplier_name, po.status
            FROM purchase_orders po
            JOIN suppliers s ON po.supplier_id = s.id
            WHERE po.id = ? AND po.status IN ('ordered', 'partially_received')
        ");
        $stmt->execute([$order_id]);
        $order = $stmt->fetch();

        if (!$order) {
            $_SESSION['error'] = "该订单不存在或状态不允许入库";
            header("Location: purchase_orders.php");
            exit;
        }

        // 获取订单的项目
        $stmt = $pdo->prepare("
            SELECT 
                poi.id, 
                p.name AS product_name, 
                p.specification,
                p.unit,
                poi.quantity, 
                poi.received_quantity,
                (poi.quantity - poi.received_quantity) AS remaining_quantity
            FROM purchase_order_items poi
            JOIN products p ON poi.product_id = p.id
            WHERE poi.purchase_order_id = ? AND poi.quantity > poi.received_quantity
        ");
        $stmt->execute([$order_id]);
        $orderItems = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = "获取订单信息失败：" . $e->getMessage();
    }
} else {
    // 否则获取所有待入库的订单项
    try {
        $stmt = $pdo->query("
            SELECT 
                poi.id, 
                po.order_number,
                s.name AS supplier_name,
                p.name AS product_name, 
                p.specification,
                p.unit,
                poi.quantity, 
                poi.received_quantity,
                (poi.quantity - poi.received_quantity) AS remaining_quantity
            FROM purchase_order_items poi
            JOIN purchase_orders po ON poi.purchase_order_id = po.id
            JOIN products p ON poi.product_id = p.id
            JOIN suppliers s ON po.supplier_id = s.id
            WHERE po.status IN ('ordered', 'partially_received') 
            AND poi.quantity > poi.received_quantity
            ORDER BY po.order_date DESC
        ");
        $orderItems = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = "获取待入库物料失败：" . $e->getMessage();
    }
}

// 获取可存放原料的仓库位置
try {
    $stmt = $pdo->query("
        SELECT id, name, temperature_controlled, humidity_controlled
        FROM storage_locations
        ORDER BY name
    ");
    $locations = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取仓库位置失败：" . $e->getMessage();
}

// 获取质检人员列表（简化为所有用户）
try {
    $stmt = $pdo->query("
        SELECT id, username, full_name
        FROM users
        WHERE is_active = 1
        ORDER BY username
    ");
    $inspectors = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取质检人员失败：" . $e->getMessage();
}

// 获取最近的入库记录
try {
    $stmt = $pdo->query("
        SELECT 
            mr.id,
            mr.received_date,
            p.name AS product_name,
            mr.received_quantity,
            p.unit,
            mr.batch_number,
            mr.quality_check_result,
            u.username AS inspector_name,
            sl.name AS location_name,
            po.order_number
        FROM material_receiving mr
        LEFT JOIN products p ON mr.product_id = p.id
        LEFT JOIN users u ON mr.inspector_id = u.id
        LEFT JOIN storage_locations sl ON mr.storage_location_id = sl.id
        LEFT JOIN purchase_order_items poi ON mr.purchase_order_item_id = poi.id
        LEFT JOIN purchase_orders po ON poi.purchase_order_id = po.id
        ORDER BY mr.received_date DESC
        LIMIT 10
    ");
    $recentReceipts = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取入库记录失败：" . $e->getMessage();
}

// 质检结果映射
$qualityResultDisplay = [
    'passed' => ['text' => '通过', 'class' => '已完成'],
    'failed' => ['text' => '不合格', 'class' => '待处理'],
    'pending' => ['text' => '待检验', 'class' => '进行中']
];
?>
<!DOCTYPE html>
<html>

<head>
    <title>采购入库与检验</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .receipt-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 15px;
            background-color: #fff;
        }

        .batch-info {
            font-size: 16px;
            font-weight: bold;
            color: #2c3e50;
            margin-bottom: 10px;
            display: flex;
            justify-content: space-between;
        }

        .receipt-info {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 10px;
        }

        .info-item {
            margin-bottom: 5px;
        }

        .info-label {
            font-weight: bold;
            color: #555;
        }

        .form-info {
            background-color: #f8f9fa;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 20px;
        }

        .form-info-title {
            font-weight: bold;
            margin-bottom: 10px;
            color: #2c3e50;
        }

        .radio-group {
            display: flex;
            gap: 15px;
            margin: 10px 0;
        }

        .radio-option {
            display: flex;
            align-items: center;
            gap: 5px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>采购入库与检验</h2>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <?php if ($order_id && isset($order)): ?>
            <div class="form-info">
                <div class="form-info-title">订单信息</div>
                <div>订单编号: <?= htmlspecialchars($order['order_number']) ?></div>
                <div>供应商: <?= htmlspecialchars($order['supplier_name']) ?></div>
                <div>当前状态: <?= htmlspecialchars($order['status']) ?></div>
            </div>
        <?php endif; ?>

        <?php if (empty($orderItems)): ?>
            <div class="empty-state">
                <p>目前没有待入库的采购订单项</p>
                <a href="purchase_orders.php" class="btn">返回采购订单列表</a>
            </div>
        <?php else: ?>
            <!-- 入库表单 -->
            <div class="form-container">
                <h3>录入入库信息</h3>
                <form method="POST" action="material_receiving_process.php">
                    <?= csrf_field() ?>

                    <?php if ($order_id): ?>
                        <input type="hidden" name="order_id" value="<?= $order_id ?>">
                    <?php else: ?>
                        <div class="form-group">
                            <label>选择待入库项目</label>
                            <select name="order_item_id" required>
                                <option value="">请选择</option>
                                <?php foreach ($orderItems as $item): ?>
                                    <option value="<?= $item['id'] ?>">
                                        <?= htmlspecialchars($item['order_number']) ?> -
                                        <?= htmlspecialchars($item['supplier_name']) ?> -
                                        <?= htmlspecialchars($item['product_name']) ?>
                                        (<?= htmlspecialchars($item['specification'] ?? '无规格') ?>) -
                                        剩余: <?= $item['remaining_quantity'] ?> <?= htmlspecialchars($item['unit']) ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    <?php endif; ?>

                    <?php if ($order_id): ?>
                        <div class="form-group">
                            <label>选择物料</label>
                            <select name="order_item_id" required>
                                <option value="">请选择</option>
                                <?php foreach ($orderItems as $item): ?>
                                    <option value="<?= $item['id'] ?>">
                                        <?= htmlspecialchars($item['product_name']) ?>
                                        (<?= htmlspecialchars($item['specification'] ?? '无规格') ?>) -
                                        剩余: <?= $item['remaining_quantity'] ?> <?= htmlspecialchars($item['unit']) ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    <?php endif; ?>

                    <div class="form-group">
                        <label>入库日期</label>
                        <input type="datetime-local" name="received_date" required value="<?= date('Y-m-d\TH:i') ?>">
                    </div>

                    <div class="form-group">
                        <label>入库数量</label>
                        <input type="number" name="received_quantity" step="0.01" min="0.01" required>
                    </div>

                    <div class="row mb-3">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="lot_number">批次号</label>
                                <input type="text" class="form-control" id="lot_number" name="lot_number" value="<?= 'LOT-' . date('YmdHis') . '-' . rand(1000, 9999) ?>" readonly>
                                <small class="form-text text-muted">系统自动生成的批次号</small>
                            </div>
                        </div>
                    </div>

                    <div class="form-group">
                        <label>质检结果</label>
                        <div class="radio-group">
                            <div class="radio-option">
                                <input type="radio" id="passed" name="quality_check_result" value="passed" checked>
                                <label for="passed">通过</label>
                            </div>
                            <div class="radio-option">
                                <input type="radio" id="failed" name="quality_check_result" value="failed">
                                <label for="failed">不合格</label>
                            </div>
                            <div class="radio-option">
                                <input type="radio" id="pending" name="quality_check_result" value="pending">
                                <label for="pending">待检验</label>
                            </div>
                        </div>
                    </div>

                    <div class="form-group">
                        <label>质检员</label>
                        <select name="inspector_id">
                            <option value="">请选择</option>
                            <?php foreach ($inspectors as $inspector): ?>
                                <option value="<?= $inspector['id'] ?>" <?= ($inspector['id'] == $_SESSION['user_id']) ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($inspector['username']) ?>
                                    <?= $inspector['full_name'] ? '(' . htmlspecialchars($inspector['full_name']) . ')' : '' ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>入库位置</label>
                        <select name="storage_location_id" required>
                            <option value="">请选择</option>
                            <?php foreach ($locations as $location): ?>
                                <option value="<?= $location['id'] ?>">
                                    <?= htmlspecialchars($location['name']) ?>
                                    <?= $location['temperature_controlled'] ? ' (温控)' : '' ?>
                                    <?= $location['humidity_controlled'] ? ' (湿控)' : '' ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>检验备注</label>
                        <textarea name="inspection_notes" rows="4" placeholder="输入质检相关信息，例如：水分含量、杂质率等"></textarea>
                    </div>

                    <div class="form-group">
                        <button type="submit" class="btn">提交入库记录</button>
                        <?php if ($order_id): ?>
                            <a href="purchase_orders.php" class="btn" style="background-color: #6c757d; margin-left: 10px;">返回订单列表</a>
                        <?php endif; ?>
                    </div>
                </form>
            </div>
        <?php endif; ?>

        <!-- 最近入库记录 -->
        <div class="table-container">
            <h3>最近入库记录</h3>

            <?php if (empty($recentReceipts)): ?>
                <div class="empty-state">
                    <p>暂无入库记录</p>
                </div>
            <?php else: ?>
                <?php foreach ($recentReceipts as $receipt): ?>
                    <?php
                    // 根据质检结果确定显示样式
                    $qualityInfo = $qualityResultDisplay[$receipt['quality_check_result']] ?? ['text' => $receipt['quality_check_result'], 'class' => ''];
                    ?>
                    <div class="receipt-card">
                        <div class="batch-info">
                            <div>批次: <?= htmlspecialchars($receipt['batch_number']) ?></div>
                            <div class="status-tag <?= $qualityInfo['class'] ?>"><?= $qualityInfo['text'] ?></div>
                        </div>
                        <div class="receipt-info">
                            <div class="info-item">
                                <span class="info-label">物料：</span>
                                <?= htmlspecialchars($receipt['product_name']) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">数量：</span>
                                <?= $receipt['received_quantity'] ?> <?= htmlspecialchars($receipt['unit']) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">采购订单：</span>
                                <?= htmlspecialchars($receipt['order_number'] ?? '直接入库') ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">入库日期：</span>
                                <?= date('Y-m-d H:i', strtotime($receipt['received_date'])) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">质检员：</span>
                                <?= htmlspecialchars($receipt['inspector_name'] ?? '未指定') ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">仓库位置：</span>
                                <?= htmlspecialchars($receipt['location_name'] ?? '未指定') ?>
                            </div>
                        </div>
                        <div style="margin-top: 10px; text-align: right;">
                            <a href="material_receiving_detail.php?id=<?= $receipt['id'] ?>" class="btn-link">查看详情</a>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>