<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取供应商ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    $_SESSION['error'] = "无效的供应商ID";
    header("Location: supplier_management.php");
    exit;
}

$supplier_id = (int)$_GET['id'];

// 表单处理
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // CSRF验证
    if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
        $_SESSION['error'] = "安全验证失败，请重试";
        header("Location: supplier_management.php");
        exit;
    }

    // 获取表单数据
    $name = trim($_POST['name'] ?? '');
    $contact_person = trim($_POST['contact_person'] ?? '');
    $phone = trim($_POST['phone'] ?? '');
    $address = trim($_POST['address'] ?? '');
    $rating = !empty($_POST['rating']) ? (int)$_POST['rating'] : null;

    // 验证数据
    if (empty($name)) {
        $_SESSION['error'] = "供应商名称不能为空";
        header("Location: supplier_edit.php?id=$supplier_id");
        exit;
    }

    try {
        $pdo->beginTransaction();

        // 检查供应商名称是否已存在（排除当前供应商）
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM suppliers WHERE name = ? AND id != ?");
        $stmt->execute([$name, $supplier_id]);
        if ($stmt->fetchColumn() > 0) {
            throw new Exception("供应商名称已存在");
        }

        // 获取原供应商数据（用于记录日志）
        $stmt = $pdo->prepare("SELECT * FROM suppliers WHERE id = ?");
        $stmt->execute([$supplier_id]);
        $oldData = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$oldData) {
            throw new Exception("供应商不存在");
        }

        // 更新供应商记录
        $stmt = $pdo->prepare("
            UPDATE suppliers 
            SET name = ?, contact_person = ?, phone = ?, address = ?, rating = ? 
            WHERE id = ?
        ");
        $stmt->execute([$name, $contact_person, $phone, $address, $rating, $supplier_id]);

        // 记录操作日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '更新供应商',
            'supplier',
            $supplier_id,
            json_encode([
                'old' => $oldData,
                'new' => [
                    'name' => $name,
                    'contact_person' => $contact_person,
                    'phone' => $phone,
                    'address' => $address,
                    'rating' => $rating
                ]
            ]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "供应商信息已更新";
        header("Location: supplier_management.php");
        exit;
    } catch (PDOException $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "操作失败：" . $e->getMessage();
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = $e->getMessage();
    }
}

// 获取供应商数据
try {
    $stmt = $pdo->prepare("SELECT * FROM suppliers WHERE id = ?");
    $stmt->execute([$supplier_id]);
    $supplier = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$supplier) {
        $_SESSION['error'] = "供应商不存在";
        header("Location: supplier_management.php");
        exit;
    }
} catch (PDOException $e) {
    $_SESSION['error'] = "数据获取失败：" . $e->getMessage();
    header("Location: supplier_management.php");
    exit;
}
?>
<!DOCTYPE html>
<html>

<head>
    <title>编辑供应商 - <?= htmlspecialchars($supplier['name']) ?></title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>编辑供应商</h2>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <div class="form-container">
            <form method="POST">
                <?= csrf_field() ?>
                <div class="form-group">
                    <label>供应商名称</label>
                    <input type="text" name="name" value="<?= htmlspecialchars($supplier['name']) ?>" required maxlength="100">
                </div>

                <div class="form-group">
                    <label>联系人</label>
                    <input type="text" name="contact_person" value="<?= htmlspecialchars($supplier['contact_person'] ?? '') ?>" maxlength="50">
                </div>

                <div class="form-group">
                    <label>联系电话</label>
                    <input type="text" name="phone" value="<?= htmlspecialchars($supplier['phone'] ?? '') ?>" maxlength="20">
                </div>

                <div class="form-group">
                    <label>地址</label>
                    <input type="text" name="address" value="<?= htmlspecialchars($supplier['address'] ?? '') ?>" maxlength="255">
                </div>

                <div class="form-group">
                    <label>供应商评级 (1-5星)</label>
                    <select name="rating">
                        <option value="">未评级</option>
                        <?php for ($i = 1; $i <= 5; $i++): ?>
                            <option value="<?= $i ?>" <?= ($supplier['rating'] == $i) ? 'selected' : '' ?>><?= $i ?> 星</option>
                        <?php endfor; ?>
                    </select>
                </div>

                <div class="form-group" style="display: flex; gap: 10px;">
                    <button type="submit" class="btn">保存修改</button>
                    <a href="supplier_management.php" style="flex: 1; text-align: center; padding: 12px; background-color: #6c757d; color: white; text-decoration: none; border-radius: 4px;">返回列表</a>
                </div>
            </form>
        </div>
    </div>
</body>

</html>