<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 处理供应商删除
if (isset($_GET['delete'])) {
    $supplier_id = (int)$_GET['delete'];

    try {
        $pdo->beginTransaction();

        // 检查该供应商是否有关联的采购订单
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM purchase_orders WHERE supplier_id = ?");
        $stmt->execute([$supplier_id]);
        $orderCount = $stmt->fetchColumn();

        if ($orderCount > 0) {
            throw new Exception("该供应商存在关联的采购订单，无法删除");
        }

        // 删除供应商
        $stmt = $pdo->prepare("DELETE FROM suppliers WHERE id = ?");
        $stmt->execute([$supplier_id]);

        // 记录操作日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '删除供应商',
            'supplier',
            $supplier_id,
            json_encode(['supplier_id' => $supplier_id]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "供应商已成功删除";
    } catch (PDOException $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "操作失败：" . $e->getMessage();
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = $e->getMessage();
    }

    header("Location: supplier_management.php");
    exit;
}

// 获取所有供应商
$suppliers = $pdo->query("
    SELECT id, name, contact_person, phone, address, rating, 
           created_at, updated_at 
    FROM suppliers 
    ORDER BY name
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>供应商管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .rating {
            color: #f39c12;
            font-size: 18px;
        }

        .supplier-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 15px;
            background-color: #fff;
        }

        .supplier-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
            margin-bottom: 10px;
        }

        .supplier-name {
            font-size: 18px;
            font-weight: bold;
            color: #2c3e50;
        }

        .supplier-info {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 10px;
        }

        .info-item {
            margin-bottom: 5px;
        }

        .info-label {
            font-weight: bold;
            color: #555;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>供应商管理</h2>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <!-- 供应商创建表单 -->
        <div class="form-container">
            <h3>添加新供应商</h3>
            <form method="POST" action="supplier_create.php">
                <?= csrf_field() ?>
                <div class="form-group">
                    <label>供应商名称</label>
                    <input type="text" name="name" required maxlength="100">
                </div>

                <div class="form-group">
                    <label>联系人</label>
                    <input type="text" name="contact_person" maxlength="50">
                </div>

                <div class="form-group">
                    <label>联系电话</label>
                    <input type="text" name="phone" maxlength="20">
                </div>

                <div class="form-group">
                    <label>地址</label>
                    <input type="text" name="address" maxlength="255">
                </div>

                <div class="form-group">
                    <label>供应商评级 (1-5星)</label>
                    <select name="rating">
                        <option value="">未评级</option>
                        <?php for ($i = 1; $i <= 5; $i++): ?>
                            <option value="<?= $i ?>"><?= $i ?> 星</option>
                        <?php endfor; ?>
                    </select>
                </div>

                <button type="submit" class="btn">添加供应商</button>
            </form>
        </div>

        <!-- 供应商列表 -->
        <div class="table-container">
            <h3>供应商列表</h3>

            <?php if (empty($suppliers)): ?>
                <div class="empty-state">
                    <p>暂无供应商记录，请添加新供应商</p>
                </div>
            <?php else: ?>
                <?php foreach ($suppliers as $supplier): ?>
                    <div class="supplier-card">
                        <div class="supplier-header">
                            <div class="supplier-name"><?= htmlspecialchars($supplier['name']) ?></div>
                            <div class="rating">
                                <?php
                                $rating = intval($supplier['rating'] ?? 0);
                                for ($i = 0; $i < $rating; $i++) {
                                    echo "★";
                                }
                                for ($i = $rating; $i < 5; $i++) {
                                    echo "☆";
                                }
                                ?>
                            </div>
                        </div>
                        <div class="supplier-info">
                            <div class="info-item">
                                <span class="info-label">联系人：</span>
                                <?= htmlspecialchars($supplier['contact_person'] ?? '未设置') ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">联系电话：</span>
                                <?= htmlspecialchars($supplier['phone'] ?? '未设置') ?>
                            </div>
                            <div class="info-item" style="grid-column: 1 / span 2;">
                                <span class="info-label">地址：</span>
                                <?= htmlspecialchars($supplier['address'] ?? '未设置') ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">创建时间：</span>
                                <?= date('Y-m-d', strtotime($supplier['created_at'])) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">最后更新：</span>
                                <?= date('Y-m-d', strtotime($supplier['updated_at'])) ?>
                            </div>
                        </div>
                        <div style="margin-top: 10px; text-align: right;">
                            <a href="supplier_edit.php?id=<?= $supplier['id'] ?>" class="btn-edit">编辑</a>
                            <a href="supplier_management.php?delete=<?= $supplier['id'] ?>"
                                onclick="return confirm('确定要删除该供应商吗？此操作不可恢复')"
                                class="btn-delete">删除</a>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>